# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/evm/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.injective.evm.v1 import access_tuple_pb2 as injective_dot_evm_dot_v1_dot_access__tuple__pb2
from pyinjective.proto.injective.evm.v1 import log_pb2 as injective_dot_evm_dot_v1_dot_log__pb2
from pyinjective.proto.injective.evm.v1 import params_pb2 as injective_dot_evm_dot_v1_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19injective/evm/v1/tx.proto\x12\x10injective.evm.v1\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/protobuf/any.proto\x1a#injective/evm/v1/access_tuple.proto\x1a\x1ainjective/evm/v1/log.proto\x1a\x1dinjective/evm/v1/params.proto\"\x80\x02\n\rMsgEthereumTx\x12(\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyR\x04\x64\x61ta\x12\x19\n\x04size\x18\x02 \x01(\x01\x42\x05\xea\xde\x1f\x01-R\x04size\x12\x34\n\x0f\x64\x65precated_hash\x18\x03 \x01(\tB\x0b\xf2\xde\x1f\x07rlp:\"-\"R\x0e\x64\x65precatedHash\x12+\n\x0f\x64\x65precated_from\x18\x04 \x01(\tB\x02\x18\x01R\x0e\x64\x65precatedFrom\x12\x12\n\x04\x66rom\x18\x05 \x01(\x0cR\x04\x66rom\x12$\n\x03raw\x18\x06 \x01(\x0c\x42\x12\xc8\xde\x1f\x00\xda\xde\x1f\nEthereumTxR\x03raw:\r\x88\xa0\x1f\x00\x82\xe7\xb0*\x04\x66rom\"\x91\x02\n\x08LegacyTx\x12\x14\n\x05nonce\x18\x01 \x01(\x04R\x05nonce\x12\x36\n\tgas_price\x18\x02 \x01(\tB\x19\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x08gasPrice\x12\x1e\n\x03gas\x18\x03 \x01(\x04\x42\x0c\xe2\xde\x1f\x08GasLimitR\x03gas\x12\x0e\n\x02to\x18\x04 \x01(\tR\x02to\x12\x39\n\x05value\x18\x05 \x01(\tB#\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xe2\xde\x1f\x06\x41mountR\x05value\x12\x12\n\x04\x64\x61ta\x18\x06 \x01(\x0cR\x04\x64\x61ta\x12\x0c\n\x01v\x18\x07 \x01(\x0cR\x01v\x12\x0c\n\x01r\x18\x08 \x01(\x0cR\x01r\x12\x0c\n\x01s\x18\t \x01(\x0cR\x01s:\x0e\x88\xa0\x1f\x00\xca\xb4-\x06TxData\"\xbe\x03\n\x0c\x41\x63\x63\x65ssListTx\x12J\n\x08\x63hain_id\x18\x01 \x01(\tB/\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xe2\xde\x1f\x07\x43hainID\xea\xde\x1f\x07\x63hainIDR\x07\x63hainId\x12\x14\n\x05nonce\x18\x02 \x01(\x04R\x05nonce\x12\x36\n\tgas_price\x18\x03 \x01(\tB\x19\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x08gasPrice\x12\x1e\n\x03gas\x18\x04 \x01(\x04\x42\x0c\xe2\xde\x1f\x08GasLimitR\x03gas\x12\x0e\n\x02to\x18\x05 \x01(\tR\x02to\x12\x39\n\x05value\x18\x06 \x01(\tB#\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xe2\xde\x1f\x06\x41mountR\x05value\x12\x12\n\x04\x64\x61ta\x18\x07 \x01(\x0cR\x04\x64\x61ta\x12[\n\x08\x61\x63\x63\x65sses\x18\x08 \x03(\x0b\x32\x1d.injective.evm.v1.AccessTupleB \xc8\xde\x1f\x00\xea\xde\x1f\naccessList\xaa\xdf\x1f\nAccessListR\x08\x61\x63\x63\x65sses\x12\x0c\n\x01v\x18\t \x01(\x0cR\x01v\x12\x0c\n\x01r\x18\n \x01(\x0cR\x01r\x12\x0c\n\x01s\x18\x0b \x01(\x0cR\x01s:\x0e\x88\xa0\x1f\x00\xca\xb4-\x06TxData\"\xfc\x03\n\x0c\x44ynamicFeeTx\x12J\n\x08\x63hain_id\x18\x01 \x01(\tB/\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xe2\xde\x1f\x07\x43hainID\xea\xde\x1f\x07\x63hainIDR\x07\x63hainId\x12\x14\n\x05nonce\x18\x02 \x01(\x04R\x05nonce\x12\x39\n\x0bgas_tip_cap\x18\x03 \x01(\tB\x19\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\tgasTipCap\x12\x39\n\x0bgas_fee_cap\x18\x04 \x01(\tB\x19\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\tgasFeeCap\x12\x1e\n\x03gas\x18\x05 \x01(\x04\x42\x0c\xe2\xde\x1f\x08GasLimitR\x03gas\x12\x0e\n\x02to\x18\x06 \x01(\tR\x02to\x12\x39\n\x05value\x18\x07 \x01(\tB#\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xe2\xde\x1f\x06\x41mountR\x05value\x12\x12\n\x04\x64\x61ta\x18\x08 \x01(\x0cR\x04\x64\x61ta\x12[\n\x08\x61\x63\x63\x65sses\x18\t \x03(\x0b\x32\x1d.injective.evm.v1.AccessTupleB \xc8\xde\x1f\x00\xea\xde\x1f\naccessList\xaa\xdf\x1f\nAccessListR\x08\x61\x63\x63\x65sses\x12\x0c\n\x01v\x18\n \x01(\x0cR\x01v\x12\x0c\n\x01r\x18\x0b \x01(\x0cR\x01r\x12\x0c\n\x01s\x18\x0c \x01(\x0cR\x01s:\x0e\x88\xa0\x1f\x00\xca\xb4-\x06TxData\"\"\n\x1a\x45xtensionOptionsEthereumTx:\x04\x88\xa0\x1f\x00\"\xc3\x01\n\x15MsgEthereumTxResponse\x12\x12\n\x04hash\x18\x01 \x01(\tR\x04hash\x12)\n\x04logs\x18\x02 \x03(\x0b\x32\x15.injective.evm.v1.LogR\x04logs\x12\x10\n\x03ret\x18\x03 \x01(\x0cR\x03ret\x12\x19\n\x08vm_error\x18\x04 \x01(\tR\x07vmError\x12\x19\n\x08gas_used\x18\x05 \x01(\x04R\x07gasUsed\x12\x1d\n\nblock_hash\x18\x06 \x01(\x0cR\tblockHash:\x04\x88\xa0\x1f\x00\"\x91\x01\n\x0fMsgUpdateParams\x12\x36\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tauthority\x12\x36\n\x06params\x18\x02 \x01(\x0b\x32\x18.injective.evm.v1.ParamsB\x04\xc8\xde\x1f\x00R\x06params:\x0e\x82\xe7\xb0*\tauthority\"\x19\n\x17MsgUpdateParamsResponse2\xe9\x01\n\x03Msg\x12}\n\nEthereumTx\x12\x1f.injective.evm.v1.MsgEthereumTx\x1a\'.injective.evm.v1.MsgEthereumTxResponse\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/injective/evm/v1/ethereum_tx\x12\\\n\x0cUpdateParams\x12!.injective.evm.v1.MsgUpdateParams\x1a).injective.evm.v1.MsgUpdateParamsResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xcc\x01\n\x14\x63om.injective.evm.v1B\x07TxProtoP\x01ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\xa2\x02\x03IEX\xaa\x02\x10Injective.Evm.V1\xca\x02\x10Injective\\Evm\\V1\xe2\x02\x1cInjective\\Evm\\V1\\GPBMetadata\xea\x02\x12Injective::Evm::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.evm.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.injective.evm.v1B\007TxProtoP\001ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\242\002\003IEX\252\002\020Injective.Evm.V1\312\002\020Injective\\Evm\\V1\342\002\034Injective\\Evm\\V1\\GPBMetadata\352\002\022Injective::Evm::V1'
  _globals['_MSGETHEREUMTX'].fields_by_name['size']._loaded_options = None
  _globals['_MSGETHEREUMTX'].fields_by_name['size']._serialized_options = b'\352\336\037\001-'
  _globals['_MSGETHEREUMTX'].fields_by_name['deprecated_hash']._loaded_options = None
  _globals['_MSGETHEREUMTX'].fields_by_name['deprecated_hash']._serialized_options = b'\362\336\037\007rlp:\"-\"'
  _globals['_MSGETHEREUMTX'].fields_by_name['deprecated_from']._loaded_options = None
  _globals['_MSGETHEREUMTX'].fields_by_name['deprecated_from']._serialized_options = b'\030\001'
  _globals['_MSGETHEREUMTX'].fields_by_name['raw']._loaded_options = None
  _globals['_MSGETHEREUMTX'].fields_by_name['raw']._serialized_options = b'\310\336\037\000\332\336\037\nEthereumTx'
  _globals['_MSGETHEREUMTX']._loaded_options = None
  _globals['_MSGETHEREUMTX']._serialized_options = b'\210\240\037\000\202\347\260*\004from'
  _globals['_LEGACYTX'].fields_by_name['gas_price']._loaded_options = None
  _globals['_LEGACYTX'].fields_by_name['gas_price']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int'
  _globals['_LEGACYTX'].fields_by_name['gas']._loaded_options = None
  _globals['_LEGACYTX'].fields_by_name['gas']._serialized_options = b'\342\336\037\010GasLimit'
  _globals['_LEGACYTX'].fields_by_name['value']._loaded_options = None
  _globals['_LEGACYTX'].fields_by_name['value']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int\342\336\037\006Amount'
  _globals['_LEGACYTX']._loaded_options = None
  _globals['_LEGACYTX']._serialized_options = b'\210\240\037\000\312\264-\006TxData'
  _globals['_ACCESSLISTTX'].fields_by_name['chain_id']._loaded_options = None
  _globals['_ACCESSLISTTX'].fields_by_name['chain_id']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int\342\336\037\007ChainID\352\336\037\007chainID'
  _globals['_ACCESSLISTTX'].fields_by_name['gas_price']._loaded_options = None
  _globals['_ACCESSLISTTX'].fields_by_name['gas_price']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int'
  _globals['_ACCESSLISTTX'].fields_by_name['gas']._loaded_options = None
  _globals['_ACCESSLISTTX'].fields_by_name['gas']._serialized_options = b'\342\336\037\010GasLimit'
  _globals['_ACCESSLISTTX'].fields_by_name['value']._loaded_options = None
  _globals['_ACCESSLISTTX'].fields_by_name['value']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int\342\336\037\006Amount'
  _globals['_ACCESSLISTTX'].fields_by_name['accesses']._loaded_options = None
  _globals['_ACCESSLISTTX'].fields_by_name['accesses']._serialized_options = b'\310\336\037\000\352\336\037\naccessList\252\337\037\nAccessList'
  _globals['_ACCESSLISTTX']._loaded_options = None
  _globals['_ACCESSLISTTX']._serialized_options = b'\210\240\037\000\312\264-\006TxData'
  _globals['_DYNAMICFEETX'].fields_by_name['chain_id']._loaded_options = None
  _globals['_DYNAMICFEETX'].fields_by_name['chain_id']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int\342\336\037\007ChainID\352\336\037\007chainID'
  _globals['_DYNAMICFEETX'].fields_by_name['gas_tip_cap']._loaded_options = None
  _globals['_DYNAMICFEETX'].fields_by_name['gas_tip_cap']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int'
  _globals['_DYNAMICFEETX'].fields_by_name['gas_fee_cap']._loaded_options = None
  _globals['_DYNAMICFEETX'].fields_by_name['gas_fee_cap']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int'
  _globals['_DYNAMICFEETX'].fields_by_name['gas']._loaded_options = None
  _globals['_DYNAMICFEETX'].fields_by_name['gas']._serialized_options = b'\342\336\037\010GasLimit'
  _globals['_DYNAMICFEETX'].fields_by_name['value']._loaded_options = None
  _globals['_DYNAMICFEETX'].fields_by_name['value']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int\342\336\037\006Amount'
  _globals['_DYNAMICFEETX'].fields_by_name['accesses']._loaded_options = None
  _globals['_DYNAMICFEETX'].fields_by_name['accesses']._serialized_options = b'\310\336\037\000\352\336\037\naccessList\252\337\037\nAccessList'
  _globals['_DYNAMICFEETX']._loaded_options = None
  _globals['_DYNAMICFEETX']._serialized_options = b'\210\240\037\000\312\264-\006TxData'
  _globals['_EXTENSIONOPTIONSETHEREUMTX']._loaded_options = None
  _globals['_EXTENSIONOPTIONSETHEREUMTX']._serialized_options = b'\210\240\037\000'
  _globals['_MSGETHEREUMTXRESPONSE']._loaded_options = None
  _globals['_MSGETHEREUMTXRESPONSE']._serialized_options = b'\210\240\037\000'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSG'].methods_by_name['EthereumTx']._loaded_options = None
  _globals['_MSG'].methods_by_name['EthereumTx']._serialized_options = b'\202\323\344\223\002\037\"\035/injective/evm/v1/ethereum_tx'
  _globals['_MSGETHEREUMTX']._serialized_start=275
  _globals['_MSGETHEREUMTX']._serialized_end=531
  _globals['_LEGACYTX']._serialized_start=534
  _globals['_LEGACYTX']._serialized_end=807
  _globals['_ACCESSLISTTX']._serialized_start=810
  _globals['_ACCESSLISTTX']._serialized_end=1256
  _globals['_DYNAMICFEETX']._serialized_start=1259
  _globals['_DYNAMICFEETX']._serialized_end=1767
  _globals['_EXTENSIONOPTIONSETHEREUMTX']._serialized_start=1769
  _globals['_EXTENSIONOPTIONSETHEREUMTX']._serialized_end=1803
  _globals['_MSGETHEREUMTXRESPONSE']._serialized_start=1806
  _globals['_MSGETHEREUMTXRESPONSE']._serialized_end=2001
  _globals['_MSGUPDATEPARAMS']._serialized_start=2004
  _globals['_MSGUPDATEPARAMS']._serialized_end=2149
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=2151
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=2176
  _globals['_MSG']._serialized_start=2179
  _globals['_MSG']._serialized_end=2412
# @@protoc_insertion_point(module_scope)



from dataclasses import dataclass
from decimal import ROUND_UP, Decimal
from typing import Optional

from pyinjective.constant import ADDITIONAL_CHAIN_FORMAT_DECIMALS
from pyinjective.core.token import Token
from pyinjective.utils.denom import Denom


@dataclass(eq=True, frozen=True)
class SpotMarket:
    id: str
    status: str
    ticker: str
    base_token: Token
    quote_token: Token
    maker_fee_rate: Decimal
    taker_fee_rate: Decimal
    service_provider_fee: Decimal
    min_price_tick_size: Decimal
    min_quantity_tick_size: Decimal
    min_notional: Decimal

    def quantity_to_chain_format(self, human_readable_value: Decimal) -> Decimal:
        chain_formatted_value = human_readable_value * Decimal(f"1e{self.base_token.decimals}")
        quantized_value = chain_formatted_value // self.min_quantity_tick_size * self.min_quantity_tick_size
        extended_chain_formatted_value = quantized_value * Decimal(f"1e{ADDITIONAL_CHAIN_FORMAT_DECIMALS}")

        return extended_chain_formatted_value

    def price_to_chain_format(self, human_readable_value: Decimal) -> Decimal:
        decimals = self.quote_token.decimals - self.base_token.decimals
        chain_formatted_value = human_readable_value * Decimal(f"1e{decimals}")
        quantized_value = (chain_formatted_value // self.min_price_tick_size) * self.min_price_tick_size
        extended_chain_formatted_value = quantized_value * Decimal(f"1e{ADDITIONAL_CHAIN_FORMAT_DECIMALS}")

        return extended_chain_formatted_value

    def notional_to_chain_format(self, human_readable_value: Decimal) -> Decimal:
        decimals = self.quote_token.decimals
        chain_formatted_value = human_readable_value * Decimal(f"1e{decimals}")
        quantized_balue = chain_formatted_value.quantize(Decimal("1"), rounding=ROUND_UP)
        extended_chain_formatted_value = quantized_balue * Decimal(f"1e{ADDITIONAL_CHAIN_FORMAT_DECIMALS}")

        return extended_chain_formatted_value

    def quantity_from_chain_format(self, chain_value: Decimal) -> Decimal:
        return chain_value / Decimal(f"1e{self.base_token.decimals}")

    def price_from_chain_format(self, chain_value: Decimal) -> Decimal:
        decimals = self.base_token.decimals - self.quote_token.decimals
        return chain_value * Decimal(f"1e{decimals}")

    def notional_from_chain_format(self, chain_value: Decimal) -> Decimal:
        return chain_value / Decimal(f"1e{self.quote_token.decimals}")

    def quantity_from_extended_chain_format(self, chain_value: Decimal) -> Decimal:
        return self._from_extended_chain_format(chain_value=self.quantity_from_chain_format(chain_value=chain_value))

    def price_from_extended_chain_format(self, chain_value: Decimal) -> Decimal:
        return self._from_extended_chain_format(chain_value=self.price_from_chain_format(chain_value=chain_value))

    def notional_from_extended_chain_format(self, chain_value: Decimal) -> Decimal:
        return self._from_extended_chain_format(chain_value=self.notional_from_chain_format(chain_value=chain_value))

    def _from_extended_chain_format(self, chain_value: Decimal) -> Decimal:
        return chain_value / Decimal(f"1e{ADDITIONAL_CHAIN_FORMAT_DECIMALS}")


@dataclass(eq=True, frozen=True)
class DerivativeMarket:
    id: str
    status: str
    ticker: str
    oracle_base: str
    oracle_quote: str
    oracle_type: str
    oracle_scale_factor: int
    initial_margin_ratio: Decimal
    maintenance_margin_ratio: Decimal
    quote_token: Token
    maker_fee_rate: Decimal
    taker_fee_rate: Decimal
    service_provider_fee: Decimal
    min_price_tick_size: Decimal
    min_quantity_tick_size: Decimal
    min_notional: Decimal

    def quantity_to_chain_format(self, human_readable_value: Decimal) -> Decimal:
        # Derivative markets do not have a base market to provide the number of decimals
        chain_formatted_value = human_readable_value
        quantized_value = chain_formatted_value // self.min_quantity_tick_size * self.min_quantity_tick_size
        extended_chain_formatted_value = quantized_value * Decimal(f"1e{ADDITIONAL_CHAIN_FORMAT_DECIMALS}")

        return extended_chain_formatted_value

    def price_to_chain_format(self, human_readable_value: Decimal) -> Decimal:
        decimals = self.quote_token.decimals
        chain_formatted_value = human_readable_value * Decimal(f"1e{decimals}")
        quantized_value = (chain_formatted_value // self.min_price_tick_size) * self.min_price_tick_size
        extended_chain_formatted_value = quantized_value * Decimal(f"1e{ADDITIONAL_CHAIN_FORMAT_DECIMALS}")

        return extended_chain_formatted_value

    def margin_to_chain_format(self, human_readable_value: Decimal) -> Decimal:
        return self.notional_to_chain_format(human_readable_value=human_readable_value)

    def calculate_margin_in_chain_format(
        self, human_readable_quantity: Decimal, human_readable_price: Decimal, leverage: Decimal
    ) -> Decimal:
        chain_formatted_quantity = human_readable_quantity
        chain_formatted_price = human_readable_price * Decimal(f"1e{self.quote_token.decimals}")
        margin = (chain_formatted_price * chain_formatted_quantity) / leverage
        # We are using the min_quantity_tick_size to quantize the margin because that is the way margin is validated
        # in the chain (it might be changed to a min_notional in the future)
        quantized_margin = (margin // self.min_quantity_tick_size) * self.min_quantity_tick_size
        extended_chain_formatted_margin = quantized_margin * Decimal(f"1e{ADDITIONAL_CHAIN_FORMAT_DECIMALS}")

        return extended_chain_formatted_margin

    def notional_to_chain_format(self, human_readable_value: Decimal) -> Decimal:
        decimals = self.quote_token.decimals
        chain_formatted_value = human_readable_value * Decimal(f"1e{decimals}")
        quantized_notional = chain_formatted_value.quantize(Decimal("1"), rounding=ROUND_UP)
        extended_chain_formatted_value = quantized_notional * Decimal(f"1e{ADDITIONAL_CHAIN_FORMAT_DECIMALS}")

        return extended_chain_formatted_value

    def quantity_from_chain_format(self, chain_value: Decimal) -> Decimal:
        return chain_value

    def price_from_chain_format(self, chain_value: Decimal) -> Decimal:
        return chain_value * Decimal(f"1e-{self.quote_token.decimals}")

    def margin_from_chain_format(self, chain_value: Decimal) -> Decimal:
        return self.notional_from_chain_format(chain_value=chain_value)

    def notional_from_chain_format(self, chain_value: Decimal) -> Decimal:
        return chain_value / Decimal(f"1e{self.quote_token.decimals}")

    def quantity_from_extended_chain_format(self, chain_value: Decimal) -> Decimal:
        return self._from_extended_chain_format(chain_value=self.quantity_from_chain_format(chain_value=chain_value))

    def price_from_extended_chain_format(self, chain_value: Decimal) -> Decimal:
        return self._from_extended_chain_format(chain_value=self.price_from_chain_format(chain_value=chain_value))

    def margin_from_extended_chain_format(self, chain_value: Decimal) -> Decimal:
        return self.notional_from_extended_chain_format(chain_value=chain_value)

    def notional_from_extended_chain_format(self, chain_value: Decimal) -> Decimal:
        return self._from_extended_chain_format(chain_value=self.notional_from_chain_format(chain_value=chain_value))

    def _from_extended_chain_format(self, chain_value: Decimal) -> Decimal:
        return chain_value / Decimal(f"1e{ADDITIONAL_CHAIN_FORMAT_DECIMALS}")


@dataclass(eq=True, frozen=True)
class BinaryOptionMarket:
    id: str
    status: str
    ticker: str
    oracle_symbol: str
    oracle_provider: str
    oracle_type: str
    oracle_scale_factor: int
    expiration_timestamp: int
    settlement_timestamp: int
    quote_token: Token
    maker_fee_rate: Decimal
    taker_fee_rate: Decimal
    service_provider_fee: Decimal
    min_price_tick_size: Decimal
    min_quantity_tick_size: Decimal
    min_notional: Decimal
    settlement_price: Optional[Decimal] = None

    def quantity_to_chain_format(self, human_readable_value: Decimal, special_denom: Optional[Denom] = None) -> Decimal:
        # Binary option markets do not have a base market to provide the number of decimals
        decimals = 0 if special_denom is None else special_denom.base
        min_quantity_tick_size = (
            self.min_quantity_tick_size if special_denom is None else special_denom.min_quantity_tick_size
        )
        chain_formatted_value = human_readable_value * Decimal(f"1e{decimals}")
        quantized_value = chain_formatted_value // min_quantity_tick_size * min_quantity_tick_size
        extended_chain_formatted_value = quantized_value * Decimal(f"1e{ADDITIONAL_CHAIN_FORMAT_DECIMALS}")

        return extended_chain_formatted_value

    def price_to_chain_format(self, human_readable_value: Decimal, special_denom: Optional[Denom] = None) -> Decimal:
        decimals = self.quote_token.decimals if special_denom is None else special_denom.quote
        min_price_tick_size = self.min_price_tick_size if special_denom is None else special_denom.min_price_tick_size
        chain_formatted_value = human_readable_value * Decimal(f"1e{decimals}")
        quantized_value = (chain_formatted_value // min_price_tick_size) * min_price_tick_size
        extended_chain_formatted_value = quantized_value * Decimal(f"1e{ADDITIONAL_CHAIN_FORMAT_DECIMALS}")

        return extended_chain_formatted_value

    def margin_to_chain_format(self, human_readable_value: Decimal, special_denom: Optional[Denom] = None) -> Decimal:
        decimals = self.quote_token.decimals if special_denom is None else special_denom.quote
        min_quantity_tick_size = (
            self.min_quantity_tick_size if special_denom is None else special_denom.min_quantity_tick_size
        )
        chain_formatted_value = human_readable_value * Decimal(f"1e{decimals}")
        quantized_value = (chain_formatted_value // min_quantity_tick_size) * min_quantity_tick_size
        extended_chain_formatted_value = quantized_value * Decimal(f"1e{ADDITIONAL_CHAIN_FORMAT_DECIMALS}")

        return extended_chain_formatted_value

    def calculate_margin_in_chain_format(
        self,
        human_readable_quantity: Decimal,
        human_readable_price: Decimal,
        is_buy: bool,
        special_denom: Optional[Denom] = None,
    ) -> Decimal:
        quantity_decimals = 0 if special_denom is None else special_denom.base
        price_decimals = self.quote_token.decimals if special_denom is None else special_denom.quote
        min_quantity_tick_size = (
            self.min_quantity_tick_size if special_denom is None else special_denom.min_quantity_tick_size
        )
        price = human_readable_price if is_buy else 1 - human_readable_price
        chain_formatted_quantity = human_readable_quantity * Decimal(f"1e{quantity_decimals}")
        chain_formatted_price = price * Decimal(f"1e{price_decimals}")
        margin = chain_formatted_price * chain_formatted_quantity
        # We are using the min_quantity_tick_size to quantize the margin because that is the way margin is validated
        # in the chain (it might be changed to a min_notional in the future)
        quantized_margin = (margin // min_quantity_tick_size) * min_quantity_tick_size
        extended_chain_formatted_margin = quantized_margin * Decimal(f"1e{ADDITIONAL_CHAIN_FORMAT_DECIMALS}")

        return extended_chain_formatted_margin

    def notional_to_chain_format(self, human_readable_value: Decimal) -> Decimal:
        decimals = self.quote_token.decimals
        chain_formatted_value = human_readable_value * Decimal(f"1e{decimals}")
        quantized_value = chain_formatted_value.quantize(Decimal("1"), rounding=ROUND_UP)
        extended_chain_formatted_value = quantized_value * Decimal(f"1e{ADDITIONAL_CHAIN_FORMAT_DECIMALS}")

        return extended_chain_formatted_value

    def quantity_from_chain_format(self, chain_value: Decimal, special_denom: Optional[Denom] = None) -> Decimal:
        # Binary option markets do not have a base market to provide the number of decimals
        decimals = 0 if special_denom is None else special_denom.base
        return chain_value * Decimal(f"1e-{decimals}")

    def price_from_chain_format(self, chain_value: Decimal, special_denom: Optional[Denom] = None) -> Decimal:
        decimals = self.quote_token.decimals if special_denom is None else special_denom.quote
        return chain_value * Decimal(f"1e-{decimals}")

    def margin_from_chain_format(self, chain_value: Decimal) -> Decimal:
        return self.notional_from_chain_format(chain_value=chain_value)

    def notional_from_chain_format(self, chain_value: Decimal) -> Decimal:
        return chain_value / Decimal(f"1e{self.quote_token.decimals}")

    def quantity_from_extended_chain_format(
        self, chain_value: Decimal, special_denom: Optional[Denom] = None
    ) -> Decimal:
        return self._from_extended_chain_format(
            chain_value=self.quantity_from_chain_format(chain_value=chain_value, special_denom=special_denom)
        )

    def price_from_extended_chain_format(self, chain_value: Decimal, special_denom: Optional[Denom] = None) -> Decimal:
        return self._from_extended_chain_format(
            chain_value=self.price_from_chain_format(chain_value=chain_value, special_denom=special_denom)
        )

    def margin_from_extended_chain_format(self, chain_value: Decimal) -> Decimal:
        return self.notional_from_extended_chain_format(chain_value=chain_value)

    def notional_from_extended_chain_format(self, chain_value: Decimal) -> Decimal:
        return self._from_extended_chain_format(chain_value=self.notional_from_chain_format(chain_value=chain_value))

    def _from_extended_chain_format(self, chain_value: Decimal) -> Decimal:
        return chain_value / Decimal(f"1e{ADDITIONAL_CHAIN_FORMAT_DECIMALS}")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/types/v1/evidence.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.types.v1 import types_pb2 as cometbft_dot_types_dot_v1_dot_types__pb2
from pyinjective.proto.cometbft.types.v1 import validator_pb2 as cometbft_dot_types_dot_v1_dot_validator__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cometbft/types/v1/evidence.proto\x12\x11\x63ometbft.types.v1\x1a\x1d\x63ometbft/types/v1/types.proto\x1a!cometbft/types/v1/validator.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe6\x01\n\x08\x45vidence\x12\x62\n\x17\x64uplicate_vote_evidence\x18\x01 \x01(\x0b\x32(.cometbft.types.v1.DuplicateVoteEvidenceH\x00R\x15\x64uplicateVoteEvidence\x12o\n\x1clight_client_attack_evidence\x18\x02 \x01(\x0b\x32,.cometbft.types.v1.LightClientAttackEvidenceH\x00R\x19lightClientAttackEvidenceB\x05\n\x03sum\"\x92\x02\n\x15\x44uplicateVoteEvidence\x12.\n\x06vote_a\x18\x01 \x01(\x0b\x32\x17.cometbft.types.v1.VoteR\x05voteA\x12.\n\x06vote_b\x18\x02 \x01(\x0b\x32\x17.cometbft.types.v1.VoteR\x05voteB\x12,\n\x12total_voting_power\x18\x03 \x01(\x03R\x10totalVotingPower\x12\'\n\x0fvalidator_power\x18\x04 \x01(\x03R\x0evalidatorPower\x12\x42\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\ttimestamp\"\xcf\x02\n\x19LightClientAttackEvidence\x12J\n\x11\x63onflicting_block\x18\x01 \x01(\x0b\x32\x1d.cometbft.types.v1.LightBlockR\x10\x63onflictingBlock\x12#\n\rcommon_height\x18\x02 \x01(\x03R\x0c\x63ommonHeight\x12O\n\x14\x62yzantine_validators\x18\x03 \x03(\x0b\x32\x1c.cometbft.types.v1.ValidatorR\x13\x62yzantineValidators\x12,\n\x12total_voting_power\x18\x04 \x01(\x03R\x10totalVotingPower\x12\x42\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\ttimestamp\"M\n\x0c\x45videnceList\x12=\n\x08\x65vidence\x18\x01 \x03(\x0b\x32\x1b.cometbft.types.v1.EvidenceB\x04\xc8\xde\x1f\x00R\x08\x65videnceB\xc0\x01\n\x15\x63om.cometbft.types.v1B\rEvidenceProtoP\x01Z2github.com/cometbft/cometbft/api/cometbft/types/v1\xa2\x02\x03\x43TX\xaa\x02\x11\x43ometbft.Types.V1\xca\x02\x11\x43ometbft\\Types\\V1\xe2\x02\x1d\x43ometbft\\Types\\V1\\GPBMetadata\xea\x02\x13\x43ometbft::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.types.v1.evidence_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.cometbft.types.v1B\rEvidenceProtoP\001Z2github.com/cometbft/cometbft/api/cometbft/types/v1\242\002\003CTX\252\002\021Cometbft.Types.V1\312\002\021Cometbft\\Types\\V1\342\002\035Cometbft\\Types\\V1\\GPBMetadata\352\002\023Cometbft::Types::V1'
  _globals['_DUPLICATEVOTEEVIDENCE'].fields_by_name['timestamp']._loaded_options = None
  _globals['_DUPLICATEVOTEEVIDENCE'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_LIGHTCLIENTATTACKEVIDENCE'].fields_by_name['timestamp']._loaded_options = None
  _globals['_LIGHTCLIENTATTACKEVIDENCE'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_EVIDENCELIST'].fields_by_name['evidence']._loaded_options = None
  _globals['_EVIDENCELIST'].fields_by_name['evidence']._serialized_options = b'\310\336\037\000'
  _globals['_EVIDENCE']._serialized_start=177
  _globals['_EVIDENCE']._serialized_end=407
  _globals['_DUPLICATEVOTEEVIDENCE']._serialized_start=410
  _globals['_DUPLICATEVOTEEVIDENCE']._serialized_end=684
  _globals['_LIGHTCLIENTATTACKEVIDENCE']._serialized_start=687
  _globals['_LIGHTCLIENTATTACKEVIDENCE']._serialized_end=1022
  _globals['_EVIDENCELIST']._serialized_start=1024
  _globals['_EVIDENCELIST']._serialized_end=1101
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/bytestream/bytestream.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"google/bytestream/bytestream.proto\x12\x11google.bytestream\"r\n\x0bReadRequest\x12#\n\rresource_name\x18\x01 \x01(\tR\x0cresourceName\x12\x1f\n\x0bread_offset\x18\x02 \x01(\x03R\nreadOffset\x12\x1d\n\nread_limit\x18\x03 \x01(\x03R\treadLimit\"\"\n\x0cReadResponse\x12\x12\n\x04\x64\x61ta\x18\n \x01(\x0cR\x04\x64\x61ta\"\x8d\x01\n\x0cWriteRequest\x12#\n\rresource_name\x18\x01 \x01(\tR\x0cresourceName\x12!\n\x0cwrite_offset\x18\x02 \x01(\x03R\x0bwriteOffset\x12!\n\x0c\x66inish_write\x18\x03 \x01(\x08R\x0b\x66inishWrite\x12\x12\n\x04\x64\x61ta\x18\n \x01(\x0cR\x04\x64\x61ta\"6\n\rWriteResponse\x12%\n\x0e\x63ommitted_size\x18\x01 \x01(\x03R\rcommittedSize\">\n\x17QueryWriteStatusRequest\x12#\n\rresource_name\x18\x01 \x01(\tR\x0cresourceName\"]\n\x18QueryWriteStatusResponse\x12%\n\x0e\x63ommitted_size\x18\x01 \x01(\x03R\rcommittedSize\x12\x1a\n\x08\x63omplete\x18\x02 \x01(\x08R\x08\x63omplete2\x92\x02\n\nByteStream\x12I\n\x04Read\x12\x1e.google.bytestream.ReadRequest\x1a\x1f.google.bytestream.ReadResponse0\x01\x12L\n\x05Write\x12\x1f.google.bytestream.WriteRequest\x1a .google.bytestream.WriteResponse(\x01\x12k\n\x10QueryWriteStatus\x12*.google.bytestream.QueryWriteStatusRequest\x1a+.google.bytestream.QueryWriteStatusResponseB\xca\x01\n\x15\x63om.google.bytestreamB\x0f\x42ytestreamProtoP\x01Z;google.golang.org/genproto/googleapis/bytestream;bytestream\xa2\x02\x03GBX\xaa\x02\x11Google.Bytestream\xca\x02\x11Google\\Bytestream\xe2\x02\x1dGoogle\\Bytestream\\GPBMetadata\xea\x02\x12Google::Bytestreamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.bytestream.bytestream_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.google.bytestreamB\017BytestreamProtoP\001Z;google.golang.org/genproto/googleapis/bytestream;bytestream\242\002\003GBX\252\002\021Google.Bytestream\312\002\021Google\\Bytestream\342\002\035Google\\Bytestream\\GPBMetadata\352\002\022Google::Bytestream'
  _globals['_READREQUEST']._serialized_start=57
  _globals['_READREQUEST']._serialized_end=171
  _globals['_READRESPONSE']._serialized_start=173
  _globals['_READRESPONSE']._serialized_end=207
  _globals['_WRITEREQUEST']._serialized_start=210
  _globals['_WRITEREQUEST']._serialized_end=351
  _globals['_WRITERESPONSE']._serialized_start=353
  _globals['_WRITERESPONSE']._serialized_end=407
  _globals['_QUERYWRITESTATUSREQUEST']._serialized_start=409
  _globals['_QUERYWRITESTATUSREQUEST']._serialized_end=471
  _globals['_QUERYWRITESTATUSRESPONSE']._serialized_start=473
  _globals['_QUERYWRITESTATUSRESPONSE']._serialized_end=566
  _globals['_BYTESTREAM']._serialized_start=569
  _globals['_BYTESTREAM']._serialized_end=843
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/consensus/v1/wal.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.consensus.v1 import types_pb2 as cometbft_dot_consensus_dot_v1_dot_types__pb2
from pyinjective.proto.cometbft.types.v1 import events_pb2 as cometbft_dot_types_dot_v1_dot_events__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63ometbft/consensus/v1/wal.proto\x12\x15\x63ometbft.consensus.v1\x1a!cometbft/consensus/v1/types.proto\x1a\x1e\x63ometbft/types/v1/events.proto\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xaf\x01\n\x07MsgInfo\x12\x36\n\x03msg\x18\x01 \x01(\x0b\x32\x1e.cometbft.consensus.v1.MessageB\x04\xc8\xde\x1f\x00R\x03msg\x12#\n\x07peer_id\x18\x02 \x01(\tB\n\xe2\xde\x1f\x06PeerIDR\x06peerId\x12G\n\x0creceive_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x01\x90\xdf\x1f\x01R\x0breceiveTime\"\x90\x01\n\x0bTimeoutInfo\x12?\n\x08\x64uration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01R\x08\x64uration\x12\x16\n\x06height\x18\x02 \x01(\x03R\x06height\x12\x14\n\x05round\x18\x03 \x01(\x05R\x05round\x12\x12\n\x04step\x18\x04 \x01(\rR\x04step\"#\n\tEndHeight\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\"\xbb\x02\n\nWALMessage\x12]\n\x16\x65vent_data_round_state\x18\x01 \x01(\x0b\x32&.cometbft.types.v1.EventDataRoundStateH\x00R\x13\x65ventDataRoundState\x12;\n\x08msg_info\x18\x02 \x01(\x0b\x32\x1e.cometbft.consensus.v1.MsgInfoH\x00R\x07msgInfo\x12G\n\x0ctimeout_info\x18\x03 \x01(\x0b\x32\".cometbft.consensus.v1.TimeoutInfoH\x00R\x0btimeoutInfo\x12\x41\n\nend_height\x18\x04 \x01(\x0b\x32 .cometbft.consensus.v1.EndHeightH\x00R\tendHeightB\x05\n\x03sum\"\x80\x01\n\x0fTimedWALMessage\x12\x38\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\x04time\x12\x33\n\x03msg\x18\x02 \x01(\x0b\x32!.cometbft.consensus.v1.WALMessageR\x03msgB\xd3\x01\n\x19\x63om.cometbft.consensus.v1B\x08WalProtoP\x01Z6github.com/cometbft/cometbft/api/cometbft/consensus/v1\xa2\x02\x03\x43\x43X\xaa\x02\x15\x43ometbft.Consensus.V1\xca\x02\x15\x43ometbft\\Consensus\\V1\xe2\x02!Cometbft\\Consensus\\V1\\GPBMetadata\xea\x02\x17\x43ometbft::Consensus::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.consensus.v1.wal_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.cometbft.consensus.v1B\010WalProtoP\001Z6github.com/cometbft/cometbft/api/cometbft/consensus/v1\242\002\003CCX\252\002\025Cometbft.Consensus.V1\312\002\025Cometbft\\Consensus\\V1\342\002!Cometbft\\Consensus\\V1\\GPBMetadata\352\002\027Cometbft::Consensus::V1'
  _globals['_MSGINFO'].fields_by_name['msg']._loaded_options = None
  _globals['_MSGINFO'].fields_by_name['msg']._serialized_options = b'\310\336\037\000'
  _globals['_MSGINFO'].fields_by_name['peer_id']._loaded_options = None
  _globals['_MSGINFO'].fields_by_name['peer_id']._serialized_options = b'\342\336\037\006PeerID'
  _globals['_MSGINFO'].fields_by_name['receive_time']._loaded_options = None
  _globals['_MSGINFO'].fields_by_name['receive_time']._serialized_options = b'\310\336\037\001\220\337\037\001'
  _globals['_TIMEOUTINFO'].fields_by_name['duration']._loaded_options = None
  _globals['_TIMEOUTINFO'].fields_by_name['duration']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _globals['_TIMEDWALMESSAGE'].fields_by_name['time']._loaded_options = None
  _globals['_TIMEDWALMESSAGE'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_MSGINFO']._serialized_start=213
  _globals['_MSGINFO']._serialized_end=388
  _globals['_TIMEOUTINFO']._serialized_start=391
  _globals['_TIMEOUTINFO']._serialized_end=535
  _globals['_ENDHEIGHT']._serialized_start=537
  _globals['_ENDHEIGHT']._serialized_end=572
  _globals['_WALMESSAGE']._serialized_start=575
  _globals['_WALMESSAGE']._serialized_end=890
  _globals['_TIMEDWALMESSAGE']._serialized_start=893
  _globals['_TIMEDWALMESSAGE']._serialized_end=1021
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/tokenfactory/v1beta1/params.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.injective.tokenfactory.v1beta1 import authorityMetadata_pb2 as injective_dot_tokenfactory_dot_v1beta1_dot_authorityMetadata__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+injective/tokenfactory/v1beta1/params.proto\x12\x1einjective.tokenfactory.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x36injective/tokenfactory/v1beta1/authorityMetadata.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x11\x61mino/amino.proto\"\xc5\x01\n\x06Params\x12\x96\x01\n\x12\x64\x65nom_creation_fee\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBM\xc8\xde\x1f\x00\xf2\xde\x1f\x19yaml:\"denom_creation_fee\"\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.CoinsR\x10\x64\x65nomCreationFee:\"\x8a\xe7\xb0*\x1dinjective/tokenfactory/ParamsB\x9f\x02\n\"com.injective.tokenfactory.v1beta1B\x0bParamsProtoP\x01ZRgithub.com/InjectiveLabs/injective-core/injective-chain/modules/tokenfactory/types\xa2\x02\x03ITX\xaa\x02\x1eInjective.Tokenfactory.V1beta1\xca\x02\x1eInjective\\Tokenfactory\\V1beta1\xe2\x02*Injective\\Tokenfactory\\V1beta1\\GPBMetadata\xea\x02 Injective::Tokenfactory::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.tokenfactory.v1beta1.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.injective.tokenfactory.v1beta1B\013ParamsProtoP\001ZRgithub.com/InjectiveLabs/injective-core/injective-chain/modules/tokenfactory/types\242\002\003ITX\252\002\036Injective.Tokenfactory.V1beta1\312\002\036Injective\\Tokenfactory\\V1beta1\342\002*Injective\\Tokenfactory\\V1beta1\\GPBMetadata\352\002 Injective::Tokenfactory::V1beta1'
  _globals['_PARAMS'].fields_by_name['denom_creation_fee']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['denom_creation_fee']._serialized_options = b'\310\336\037\000\362\336\037\031yaml:\"denom_creation_fee\"\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\212\347\260*\035injective/tokenfactory/Params'
  _globals['_PARAMS']._serialized_start=236
  _globals['_PARAMS']._serialized_end=433
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/permissions/v1beta1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from pyinjective.proto.injective.permissions.v1beta1 import params_pb2 as injective_dot_permissions_dot_v1beta1_dot_params__pb2
from pyinjective.proto.injective.permissions.v1beta1 import genesis_pb2 as injective_dot_permissions_dot_v1beta1_dot_genesis__pb2
from pyinjective.proto.injective.permissions.v1beta1 import permissions_pb2 as injective_dot_permissions_dot_v1beta1_dot_permissions__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)injective/permissions/v1beta1/query.proto\x12\x1dinjective.permissions.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a*injective/permissions/v1beta1/params.proto\x1a+injective/permissions/v1beta1/genesis.proto\x1a/injective/permissions/v1beta1/permissions.proto\"\x14\n\x12QueryParamsRequest\"Z\n\x13QueryParamsResponse\x12\x43\n\x06params\x18\x01 \x01(\x0b\x32%.injective.permissions.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\"\x1d\n\x1bQueryNamespaceDenomsRequest\"6\n\x1cQueryNamespaceDenomsResponse\x12\x16\n\x06\x64\x65noms\x18\x01 \x03(\tR\x06\x64\x65noms\"\x18\n\x16QueryNamespacesRequest\"c\n\x17QueryNamespacesResponse\x12H\n\nnamespaces\x18\x01 \x03(\x0b\x32(.injective.permissions.v1beta1.NamespaceR\nnamespaces\"-\n\x15QueryNamespaceRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\"`\n\x16QueryNamespaceResponse\x12\x46\n\tnamespace\x18\x01 \x01(\x0b\x32(.injective.permissions.v1beta1.NamespaceR\tnamespace\"D\n\x18QueryActorsByRoleRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x12\n\x04role\x18\x02 \x01(\tR\x04role\"3\n\x19QueryActorsByRoleResponse\x12\x16\n\x06\x61\x63tors\x18\x01 \x03(\tR\x06\x61\x63tors\"F\n\x18QueryRolesByActorRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x14\n\x05\x61\x63tor\x18\x02 \x01(\tR\x05\x61\x63tor\"1\n\x19QueryRolesByActorResponse\x12\x14\n\x05roles\x18\x01 \x03(\tR\x05roles\"0\n\x18QueryRoleManagersRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\"l\n\x19QueryRoleManagersResponse\x12O\n\rrole_managers\x18\x01 \x03(\x0b\x32*.injective.permissions.v1beta1.RoleManagerR\x0croleManagers\"I\n\x17QueryRoleManagerRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x18\n\x07manager\x18\x02 \x01(\tR\x07manager\"i\n\x18QueryRoleManagerResponse\x12M\n\x0crole_manager\x18\x01 \x01(\x0b\x32*.injective.permissions.v1beta1.RoleManagerR\x0broleManager\"2\n\x1aQueryPolicyStatusesRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\"s\n\x1bQueryPolicyStatusesResponse\x12T\n\x0fpolicy_statuses\x18\x01 \x03(\x0b\x32+.injective.permissions.v1beta1.PolicyStatusR\x0epolicyStatuses\"=\n%QueryPolicyManagerCapabilitiesRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\"\xa0\x01\n&QueryPolicyManagerCapabilitiesResponse\x12v\n\x1bpolicy_manager_capabilities\x18\x01 \x03(\x0b\x32\x36.injective.permissions.v1beta1.PolicyManagerCapabilityR\x19policyManagerCapabilities\",\n\x14QueryVouchersRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\"b\n\x15QueryVouchersResponse\x12I\n\x08vouchers\x18\x01 \x03(\x0b\x32-.injective.permissions.v1beta1.AddressVoucherR\x08vouchers\"E\n\x13QueryVoucherRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\"\x91\x01\n\x14QueryVoucherResponse\x12y\n\x07voucher\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinBD\xc8\xde\x1f\x00\xda\xde\x1f\'github.com/cosmos/cosmos-sdk/types.Coin\xea\xde\x1f\x11voucher,omitemptyR\x07voucher\"\x19\n\x17QueryModuleStateRequest\"]\n\x18QueryModuleStateResponse\x12\x41\n\x05state\x18\x01 \x01(\x0b\x32+.injective.permissions.v1beta1.GenesisStateR\x05state2\xdd\x13\n\x05Query\x12\x9e\x01\n\x06Params\x12\x31.injective.permissions.v1beta1.QueryParamsRequest\x1a\x32.injective.permissions.v1beta1.QueryParamsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/injective/permissions/v1beta1/params\x12\xc3\x01\n\x0fNamespaceDenoms\x12:.injective.permissions.v1beta1.QueryNamespaceDenomsRequest\x1a;.injective.permissions.v1beta1.QueryNamespaceDenomsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//injective/permissions/v1beta1/namespace_denoms\x12\xae\x01\n\nNamespaces\x12\x35.injective.permissions.v1beta1.QueryNamespacesRequest\x1a\x36.injective.permissions.v1beta1.QueryNamespacesResponse\"1\x82\xd3\xe4\x93\x02+\x12)/injective/permissions/v1beta1/namespaces\x12\xb2\x01\n\tNamespace\x12\x34.injective.permissions.v1beta1.QueryNamespaceRequest\x1a\x35.injective.permissions.v1beta1.QueryNamespaceResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/injective/permissions/v1beta1/namespace/{denom}\x12\xc8\x01\n\x0cRolesByActor\x12\x37.injective.permissions.v1beta1.QueryRolesByActorRequest\x1a\x38.injective.permissions.v1beta1.QueryRolesByActorResponse\"E\x82\xd3\xe4\x93\x02?\x12=/injective/permissions/v1beta1/roles_by_actor/{denom}/{actor}\x12\xc7\x01\n\x0c\x41\x63torsByRole\x12\x37.injective.permissions.v1beta1.QueryActorsByRoleRequest\x1a\x38.injective.permissions.v1beta1.QueryActorsByRoleResponse\"D\x82\xd3\xe4\x93\x02>\x12</injective/permissions/v1beta1/actors_by_role/{denom}/{role}\x12\xbf\x01\n\x0cRoleManagers\x12\x37.injective.permissions.v1beta1.QueryRoleManagersRequest\x1a\x38.injective.permissions.v1beta1.QueryRoleManagersResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/injective/permissions/v1beta1/role_managers/{denom}\x12\xc5\x01\n\x0bRoleManager\x12\x36.injective.permissions.v1beta1.QueryRoleManagerRequest\x1a\x37.injective.permissions.v1beta1.QueryRoleManagerResponse\"E\x82\xd3\xe4\x93\x02?\x12=/injective/permissions/v1beta1/role_manager/{denom}/{manager}\x12\xc7\x01\n\x0ePolicyStatuses\x12\x39.injective.permissions.v1beta1.QueryPolicyStatusesRequest\x1a:.injective.permissions.v1beta1.QueryPolicyStatusesResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/injective/permissions/v1beta1/policy_statuses/{denom}\x12\xf4\x01\n\x19PolicyManagerCapabilities\x12\x44.injective.permissions.v1beta1.QueryPolicyManagerCapabilitiesRequest\x1a\x45.injective.permissions.v1beta1.QueryPolicyManagerCapabilitiesResponse\"J\x82\xd3\xe4\x93\x02\x44\x12\x42/injective/permissions/v1beta1/policy_manager_capabilities/{denom}\x12\xae\x01\n\x08Vouchers\x12\x33.injective.permissions.v1beta1.QueryVouchersRequest\x1a\x34.injective.permissions.v1beta1.QueryVouchersResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//injective/permissions/v1beta1/vouchers/{denom}\x12\xb4\x01\n\x07Voucher\x12\x32.injective.permissions.v1beta1.QueryVoucherRequest\x1a\x33.injective.permissions.v1beta1.QueryVoucherResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/injective/permissions/v1beta1/voucher/{denom}/{address}\x12\xbe\x01\n\x16PermissionsModuleState\x12\x36.injective.permissions.v1beta1.QueryModuleStateRequest\x1a\x37.injective.permissions.v1beta1.QueryModuleStateResponse\"3\x82\xd3\xe4\x93\x02-\x12+/injective/permissions/v1beta1/module_stateB\x98\x02\n!com.injective.permissions.v1beta1B\nQueryProtoP\x01ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/permissions/types\xa2\x02\x03IPX\xaa\x02\x1dInjective.Permissions.V1beta1\xca\x02\x1dInjective\\Permissions\\V1beta1\xe2\x02)Injective\\Permissions\\V1beta1\\GPBMetadata\xea\x02\x1fInjective::Permissions::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.permissions.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.injective.permissions.v1beta1B\nQueryProtoP\001ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/permissions/types\242\002\003IPX\252\002\035Injective.Permissions.V1beta1\312\002\035Injective\\Permissions\\V1beta1\342\002)Injective\\Permissions\\V1beta1\\GPBMetadata\352\002\037Injective::Permissions::V1beta1'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYVOUCHERRESPONSE'].fields_by_name['voucher']._loaded_options = None
  _globals['_QUERYVOUCHERRESPONSE'].fields_by_name['voucher']._serialized_options = b'\310\336\037\000\332\336\037\'github.com/cosmos/cosmos-sdk/types.Coin\352\336\037\021voucher,omitempty'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\'\022%/injective/permissions/v1beta1/params'
  _globals['_QUERY'].methods_by_name['NamespaceDenoms']._loaded_options = None
  _globals['_QUERY'].methods_by_name['NamespaceDenoms']._serialized_options = b'\202\323\344\223\0021\022//injective/permissions/v1beta1/namespace_denoms'
  _globals['_QUERY'].methods_by_name['Namespaces']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Namespaces']._serialized_options = b'\202\323\344\223\002+\022)/injective/permissions/v1beta1/namespaces'
  _globals['_QUERY'].methods_by_name['Namespace']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Namespace']._serialized_options = b'\202\323\344\223\0022\0220/injective/permissions/v1beta1/namespace/{denom}'
  _globals['_QUERY'].methods_by_name['RolesByActor']._loaded_options = None
  _globals['_QUERY'].methods_by_name['RolesByActor']._serialized_options = b'\202\323\344\223\002?\022=/injective/permissions/v1beta1/roles_by_actor/{denom}/{actor}'
  _globals['_QUERY'].methods_by_name['ActorsByRole']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ActorsByRole']._serialized_options = b'\202\323\344\223\002>\022</injective/permissions/v1beta1/actors_by_role/{denom}/{role}'
  _globals['_QUERY'].methods_by_name['RoleManagers']._loaded_options = None
  _globals['_QUERY'].methods_by_name['RoleManagers']._serialized_options = b'\202\323\344\223\0026\0224/injective/permissions/v1beta1/role_managers/{denom}'
  _globals['_QUERY'].methods_by_name['RoleManager']._loaded_options = None
  _globals['_QUERY'].methods_by_name['RoleManager']._serialized_options = b'\202\323\344\223\002?\022=/injective/permissions/v1beta1/role_manager/{denom}/{manager}'
  _globals['_QUERY'].methods_by_name['PolicyStatuses']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PolicyStatuses']._serialized_options = b'\202\323\344\223\0028\0226/injective/permissions/v1beta1/policy_statuses/{denom}'
  _globals['_QUERY'].methods_by_name['PolicyManagerCapabilities']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PolicyManagerCapabilities']._serialized_options = b'\202\323\344\223\002D\022B/injective/permissions/v1beta1/policy_manager_capabilities/{denom}'
  _globals['_QUERY'].methods_by_name['Vouchers']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Vouchers']._serialized_options = b'\202\323\344\223\0021\022//injective/permissions/v1beta1/vouchers/{denom}'
  _globals['_QUERY'].methods_by_name['Voucher']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Voucher']._serialized_options = b'\202\323\344\223\002:\0228/injective/permissions/v1beta1/voucher/{denom}/{address}'
  _globals['_QUERY'].methods_by_name['PermissionsModuleState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PermissionsModuleState']._serialized_options = b'\202\323\344\223\002-\022+/injective/permissions/v1beta1/module_state'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=342
  _globals['_QUERYPARAMSREQUEST']._serialized_end=362
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=364
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=454
  _globals['_QUERYNAMESPACEDENOMSREQUEST']._serialized_start=456
  _globals['_QUERYNAMESPACEDENOMSREQUEST']._serialized_end=485
  _globals['_QUERYNAMESPACEDENOMSRESPONSE']._serialized_start=487
  _globals['_QUERYNAMESPACEDENOMSRESPONSE']._serialized_end=541
  _globals['_QUERYNAMESPACESREQUEST']._serialized_start=543
  _globals['_QUERYNAMESPACESREQUEST']._serialized_end=567
  _globals['_QUERYNAMESPACESRESPONSE']._serialized_start=569
  _globals['_QUERYNAMESPACESRESPONSE']._serialized_end=668
  _globals['_QUERYNAMESPACEREQUEST']._serialized_start=670
  _globals['_QUERYNAMESPACEREQUEST']._serialized_end=715
  _globals['_QUERYNAMESPACERESPONSE']._serialized_start=717
  _globals['_QUERYNAMESPACERESPONSE']._serialized_end=813
  _globals['_QUERYACTORSBYROLEREQUEST']._serialized_start=815
  _globals['_QUERYACTORSBYROLEREQUEST']._serialized_end=883
  _globals['_QUERYACTORSBYROLERESPONSE']._serialized_start=885
  _globals['_QUERYACTORSBYROLERESPONSE']._serialized_end=936
  _globals['_QUERYROLESBYACTORREQUEST']._serialized_start=938
  _globals['_QUERYROLESBYACTORREQUEST']._serialized_end=1008
  _globals['_QUERYROLESBYACTORRESPONSE']._serialized_start=1010
  _globals['_QUERYROLESBYACTORRESPONSE']._serialized_end=1059
  _globals['_QUERYROLEMANAGERSREQUEST']._serialized_start=1061
  _globals['_QUERYROLEMANAGERSREQUEST']._serialized_end=1109
  _globals['_QUERYROLEMANAGERSRESPONSE']._serialized_start=1111
  _globals['_QUERYROLEMANAGERSRESPONSE']._serialized_end=1219
  _globals['_QUERYROLEMANAGERREQUEST']._serialized_start=1221
  _globals['_QUERYROLEMANAGERREQUEST']._serialized_end=1294
  _globals['_QUERYROLEMANAGERRESPONSE']._serialized_start=1296
  _globals['_QUERYROLEMANAGERRESPONSE']._serialized_end=1401
  _globals['_QUERYPOLICYSTATUSESREQUEST']._serialized_start=1403
  _globals['_QUERYPOLICYSTATUSESREQUEST']._serialized_end=1453
  _globals['_QUERYPOLICYSTATUSESRESPONSE']._serialized_start=1455
  _globals['_QUERYPOLICYSTATUSESRESPONSE']._serialized_end=1570
  _globals['_QUERYPOLICYMANAGERCAPABILITIESREQUEST']._serialized_start=1572
  _globals['_QUERYPOLICYMANAGERCAPABILITIESREQUEST']._serialized_end=1633
  _globals['_QUERYPOLICYMANAGERCAPABILITIESRESPONSE']._serialized_start=1636
  _globals['_QUERYPOLICYMANAGERCAPABILITIESRESPONSE']._serialized_end=1796
  _globals['_QUERYVOUCHERSREQUEST']._serialized_start=1798
  _globals['_QUERYVOUCHERSREQUEST']._serialized_end=1842
  _globals['_QUERYVOUCHERSRESPONSE']._serialized_start=1844
  _globals['_QUERYVOUCHERSRESPONSE']._serialized_end=1942
  _globals['_QUERYVOUCHERREQUEST']._serialized_start=1944
  _globals['_QUERYVOUCHERREQUEST']._serialized_end=2013
  _globals['_QUERYVOUCHERRESPONSE']._serialized_start=2016
  _globals['_QUERYVOUCHERRESPONSE']._serialized_end=2161
  _globals['_QUERYMODULESTATEREQUEST']._serialized_start=2163
  _globals['_QUERYMODULESTATEREQUEST']._serialized_end=2188
  _globals['_QUERYMODULESTATERESPONSE']._serialized_start=2190
  _globals['_QUERYMODULESTATERESPONSE']._serialized_end=2283
  _globals['_QUERY']._serialized_start=2286
  _globals['_QUERY']._serialized_end=4811
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/transfer/v2/packet.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)ibc/applications/transfer/v2/packet.proto\x12\x1cibc.applications.transfer.v2\"\x8f\x01\n\x17\x46ungibleTokenPacketData\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount\x12\x16\n\x06sender\x18\x03 \x01(\tR\x06sender\x12\x1a\n\x08receiver\x18\x04 \x01(\tR\x08receiver\x12\x12\n\x04memo\x18\x05 \x01(\tR\x04memoB\xfb\x01\n com.ibc.applications.transfer.v2B\x0bPacketProtoP\x01Z7github.com/cosmos/ibc-go/v8/modules/apps/transfer/types\xa2\x02\x03IAT\xaa\x02\x1cIbc.Applications.Transfer.V2\xca\x02\x1cIbc\\Applications\\Transfer\\V2\xe2\x02(Ibc\\Applications\\Transfer\\V2\\GPBMetadata\xea\x02\x1fIbc::Applications::Transfer::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.transfer.v2.packet_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.ibc.applications.transfer.v2B\013PacketProtoP\001Z7github.com/cosmos/ibc-go/v8/modules/apps/transfer/types\242\002\003IAT\252\002\034Ibc.Applications.Transfer.V2\312\002\034Ibc\\Applications\\Transfer\\V2\342\002(Ibc\\Applications\\Transfer\\V2\\GPBMetadata\352\002\037Ibc::Applications::Transfer::V2'
  _globals['_FUNGIBLETOKENPACKETDATA']._serialized_start=76
  _globals['_FUNGIBLETOKENPACKETDATA']._serialized_end=219
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_oracle_rpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#exchange/injective_oracle_rpc.proto\x12\x14injective_oracle_rpc\"\x13\n\x11OracleListRequest\"L\n\x12OracleListResponse\x12\x36\n\x07oracles\x18\x01 \x03(\x0b\x32\x1c.injective_oracle_rpc.OracleR\x07oracles\"\x9b\x01\n\x06Oracle\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12\x1f\n\x0b\x62\x61se_symbol\x18\x02 \x01(\tR\nbaseSymbol\x12!\n\x0cquote_symbol\x18\x03 \x01(\tR\x0bquoteSymbol\x12\x1f\n\x0boracle_type\x18\x04 \x01(\tR\noracleType\x12\x14\n\x05price\x18\x05 \x01(\tR\x05price\"\xa3\x01\n\x0cPriceRequest\x12\x1f\n\x0b\x62\x61se_symbol\x18\x01 \x01(\tR\nbaseSymbol\x12!\n\x0cquote_symbol\x18\x02 \x01(\tR\x0bquoteSymbol\x12\x1f\n\x0boracle_type\x18\x03 \x01(\tR\noracleType\x12.\n\x13oracle_scale_factor\x18\x04 \x01(\rR\x11oracleScaleFactor\"%\n\rPriceResponse\x12\x14\n\x05price\x18\x01 \x01(\tR\x05price\"P\n\x0ePriceV2Request\x12>\n\x07\x66ilters\x18\x01 \x03(\x0b\x32$.injective_oracle_rpc.PricePayloadV2R\x07\x66ilters\"\xa5\x01\n\x0ePricePayloadV2\x12\x1f\n\x0b\x62\x61se_symbol\x18\x01 \x01(\tR\nbaseSymbol\x12!\n\x0cquote_symbol\x18\x02 \x01(\tR\x0bquoteSymbol\x12\x1f\n\x0boracle_type\x18\x03 \x01(\tR\noracleType\x12.\n\x13oracle_scale_factor\x18\x04 \x01(\rR\x11oracleScaleFactor\"N\n\x0fPriceV2Response\x12;\n\x06prices\x18\x01 \x03(\x0b\x32#.injective_oracle_rpc.PriceV2ResultR\x06prices\"\xd7\x01\n\rPriceV2Result\x12\x1f\n\x0b\x62\x61se_symbol\x18\x01 \x01(\tR\nbaseSymbol\x12!\n\x0cquote_symbol\x18\x02 \x01(\tR\x0bquoteSymbol\x12\x1f\n\x0boracle_type\x18\x03 \x01(\tR\noracleType\x12.\n\x13oracle_scale_factor\x18\x04 \x01(\rR\x11oracleScaleFactor\x12\x14\n\x05price\x18\x05 \x01(\tR\x05price\x12\x1b\n\tmarket_id\x18\x06 \x01(\tR\x08marketId\"z\n\x13StreamPricesRequest\x12\x1f\n\x0b\x62\x61se_symbol\x18\x01 \x01(\tR\nbaseSymbol\x12!\n\x0cquote_symbol\x18\x02 \x01(\tR\x0bquoteSymbol\x12\x1f\n\x0boracle_type\x18\x03 \x01(\tR\noracleType\"J\n\x14StreamPricesResponse\x12\x14\n\x05price\x18\x01 \x01(\tR\x05price\x12\x1c\n\ttimestamp\x18\x02 \x01(\x12R\ttimestamp\"=\n\x1cStreamPricesByMarketsRequest\x12\x1d\n\nmarket_ids\x18\x01 \x03(\tR\tmarketIds\"p\n\x1dStreamPricesByMarketsResponse\x12\x14\n\x05price\x18\x01 \x01(\tR\x05price\x12\x1c\n\ttimestamp\x18\x02 \x01(\x12R\ttimestamp\x12\x1b\n\tmarket_id\x18\x03 \x01(\tR\x08marketId2\x8d\x04\n\x12InjectiveOracleRPC\x12_\n\nOracleList\x12\'.injective_oracle_rpc.OracleListRequest\x1a(.injective_oracle_rpc.OracleListResponse\x12P\n\x05Price\x12\".injective_oracle_rpc.PriceRequest\x1a#.injective_oracle_rpc.PriceResponse\x12V\n\x07PriceV2\x12$.injective_oracle_rpc.PriceV2Request\x1a%.injective_oracle_rpc.PriceV2Response\x12g\n\x0cStreamPrices\x12).injective_oracle_rpc.StreamPricesRequest\x1a*.injective_oracle_rpc.StreamPricesResponse0\x01\x12\x82\x01\n\x15StreamPricesByMarkets\x12\x32.injective_oracle_rpc.StreamPricesByMarketsRequest\x1a\x33.injective_oracle_rpc.StreamPricesByMarketsResponse0\x01\x42\xb4\x01\n\x18\x63om.injective_oracle_rpcB\x17InjectiveOracleRpcProtoP\x01Z\x17/injective_oracle_rpcpb\xa2\x02\x03IXX\xaa\x02\x12InjectiveOracleRpc\xca\x02\x12InjectiveOracleRpc\xe2\x02\x1eInjectiveOracleRpc\\GPBMetadata\xea\x02\x12InjectiveOracleRpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_oracle_rpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030com.injective_oracle_rpcB\027InjectiveOracleRpcProtoP\001Z\027/injective_oracle_rpcpb\242\002\003IXX\252\002\022InjectiveOracleRpc\312\002\022InjectiveOracleRpc\342\002\036InjectiveOracleRpc\\GPBMetadata\352\002\022InjectiveOracleRpc'
  _globals['_ORACLELISTREQUEST']._serialized_start=61
  _globals['_ORACLELISTREQUEST']._serialized_end=80
  _globals['_ORACLELISTRESPONSE']._serialized_start=82
  _globals['_ORACLELISTRESPONSE']._serialized_end=158
  _globals['_ORACLE']._serialized_start=161
  _globals['_ORACLE']._serialized_end=316
  _globals['_PRICEREQUEST']._serialized_start=319
  _globals['_PRICEREQUEST']._serialized_end=482
  _globals['_PRICERESPONSE']._serialized_start=484
  _globals['_PRICERESPONSE']._serialized_end=521
  _globals['_PRICEV2REQUEST']._serialized_start=523
  _globals['_PRICEV2REQUEST']._serialized_end=603
  _globals['_PRICEPAYLOADV2']._serialized_start=606
  _globals['_PRICEPAYLOADV2']._serialized_end=771
  _globals['_PRICEV2RESPONSE']._serialized_start=773
  _globals['_PRICEV2RESPONSE']._serialized_end=851
  _globals['_PRICEV2RESULT']._serialized_start=854
  _globals['_PRICEV2RESULT']._serialized_end=1069
  _globals['_STREAMPRICESREQUEST']._serialized_start=1071
  _globals['_STREAMPRICESREQUEST']._serialized_end=1193
  _globals['_STREAMPRICESRESPONSE']._serialized_start=1195
  _globals['_STREAMPRICESRESPONSE']._serialized_end=1269
  _globals['_STREAMPRICESBYMARKETSREQUEST']._serialized_start=1271
  _globals['_STREAMPRICESBYMARKETSREQUEST']._serialized_end=1332
  _globals['_STREAMPRICESBYMARKETSRESPONSE']._serialized_start=1334
  _globals['_STREAMPRICESBYMARKETSRESPONSE']._serialized_end=1446
  _globals['_INJECTIVEORACLERPC']._serialized_start=1449
  _globals['_INJECTIVEORACLERPC']._serialized_end=1974
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_accounts_rpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%exchange/injective_accounts_rpc.proto\x12\x16injective_accounts_rpc\";\n\x10PortfolioRequest\x12\'\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\tR\x0e\x61\x63\x63ountAddress\"[\n\x11PortfolioResponse\x12\x46\n\tportfolio\x18\x01 \x01(\x0b\x32(.injective_accounts_rpc.AccountPortfolioR\tportfolio\"\x85\x02\n\x10\x41\x63\x63ountPortfolio\x12\'\n\x0fportfolio_value\x18\x01 \x01(\tR\x0eportfolioValue\x12+\n\x11\x61vailable_balance\x18\x02 \x01(\tR\x10\x61vailableBalance\x12%\n\x0elocked_balance\x18\x03 \x01(\tR\rlockedBalance\x12%\n\x0eunrealized_pnl\x18\x04 \x01(\tR\runrealizedPnl\x12M\n\x0bsubaccounts\x18\x05 \x03(\x0b\x32+.injective_accounts_rpc.SubaccountPortfolioR\x0bsubaccounts\"\xb5\x01\n\x13SubaccountPortfolio\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12+\n\x11\x61vailable_balance\x18\x02 \x01(\tR\x10\x61vailableBalance\x12%\n\x0elocked_balance\x18\x03 \x01(\tR\rlockedBalance\x12%\n\x0eunrealized_pnl\x18\x04 \x01(\tR\runrealizedPnl\"x\n\x12OrderStatesRequest\x12*\n\x11spot_order_hashes\x18\x01 \x03(\tR\x0fspotOrderHashes\x12\x36\n\x17\x64\x65rivative_order_hashes\x18\x02 \x03(\tR\x15\x64\x65rivativeOrderHashes\"\xcd\x01\n\x13OrderStatesResponse\x12T\n\x11spot_order_states\x18\x01 \x03(\x0b\x32(.injective_accounts_rpc.OrderStateRecordR\x0fspotOrderStates\x12`\n\x17\x64\x65rivative_order_states\x18\x02 \x03(\x0b\x32(.injective_accounts_rpc.OrderStateRecordR\x15\x64\x65rivativeOrderStates\"\x8b\x03\n\x10OrderStateRecord\x12\x1d\n\norder_hash\x18\x01 \x01(\tR\torderHash\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x03 \x01(\tR\x08marketId\x12\x1d\n\norder_type\x18\x04 \x01(\tR\torderType\x12\x1d\n\norder_side\x18\x05 \x01(\tR\torderSide\x12\x14\n\x05state\x18\x06 \x01(\tR\x05state\x12\'\n\x0fquantity_filled\x18\x07 \x01(\tR\x0equantityFilled\x12-\n\x12quantity_remaining\x18\x08 \x01(\tR\x11quantityRemaining\x12\x1d\n\ncreated_at\x18\t \x01(\x12R\tcreatedAt\x12\x1d\n\nupdated_at\x18\n \x01(\x12R\tupdatedAt\x12\x14\n\x05price\x18\x0b \x01(\tR\x05price\x12\x16\n\x06margin\x18\x0c \x01(\tR\x06margin\"A\n\x16SubaccountsListRequest\x12\'\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\tR\x0e\x61\x63\x63ountAddress\";\n\x17SubaccountsListResponse\x12 \n\x0bsubaccounts\x18\x01 \x03(\tR\x0bsubaccounts\"\\\n\x1dSubaccountBalancesListRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x16\n\x06\x64\x65noms\x18\x02 \x03(\tR\x06\x64\x65noms\"g\n\x1eSubaccountBalancesListResponse\x12\x45\n\x08\x62\x61lances\x18\x01 \x03(\x0b\x32).injective_accounts_rpc.SubaccountBalanceR\x08\x62\x61lances\"\xbc\x01\n\x11SubaccountBalance\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\'\n\x0f\x61\x63\x63ount_address\x18\x02 \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x14\n\x05\x64\x65nom\x18\x03 \x01(\tR\x05\x64\x65nom\x12\x43\n\x07\x64\x65posit\x18\x04 \x01(\x0b\x32).injective_accounts_rpc.SubaccountDepositR\x07\x64\x65posit\"\xc5\x01\n\x11SubaccountDeposit\x12#\n\rtotal_balance\x18\x01 \x01(\tR\x0ctotalBalance\x12+\n\x11\x61vailable_balance\x18\x02 \x01(\tR\x10\x61vailableBalance\x12*\n\x11total_balance_usd\x18\x03 \x01(\tR\x0ftotalBalanceUsd\x12\x32\n\x15\x61vailable_balance_usd\x18\x04 \x01(\tR\x13\x61vailableBalanceUsd\"]\n SubaccountBalanceEndpointRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x14\n\x05\x64\x65nom\x18\x02 \x01(\tR\x05\x64\x65nom\"h\n!SubaccountBalanceEndpointResponse\x12\x43\n\x07\x62\x61lance\x18\x01 \x01(\x0b\x32).injective_accounts_rpc.SubaccountBalanceR\x07\x62\x61lance\"]\n\x1eStreamSubaccountBalanceRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x16\n\x06\x64\x65noms\x18\x02 \x03(\tR\x06\x64\x65noms\"\x84\x01\n\x1fStreamSubaccountBalanceResponse\x12\x43\n\x07\x62\x61lance\x18\x01 \x01(\x0b\x32).injective_accounts_rpc.SubaccountBalanceR\x07\x62\x61lance\x12\x1c\n\ttimestamp\x18\x02 \x01(\x12R\ttimestamp\"\xc1\x01\n\x18SubaccountHistoryRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x14\n\x05\x64\x65nom\x18\x02 \x01(\tR\x05\x64\x65nom\x12%\n\x0etransfer_types\x18\x03 \x03(\tR\rtransferTypes\x12\x12\n\x04skip\x18\x04 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x05 \x01(\x11R\x05limit\x12\x19\n\x08\x65nd_time\x18\x06 \x01(\x12R\x07\x65ndTime\"\xa4\x01\n\x19SubaccountHistoryResponse\x12O\n\ttransfers\x18\x01 \x03(\x0b\x32\x31.injective_accounts_rpc.SubaccountBalanceTransferR\ttransfers\x12\x36\n\x06paging\x18\x02 \x01(\x0b\x32\x1e.injective_accounts_rpc.PagingR\x06paging\"\xd5\x02\n\x19SubaccountBalanceTransfer\x12#\n\rtransfer_type\x18\x01 \x01(\tR\x0ctransferType\x12*\n\x11src_subaccount_id\x18\x02 \x01(\tR\x0fsrcSubaccountId\x12.\n\x13src_account_address\x18\x03 \x01(\tR\x11srcAccountAddress\x12*\n\x11\x64st_subaccount_id\x18\x04 \x01(\tR\x0f\x64stSubaccountId\x12.\n\x13\x64st_account_address\x18\x05 \x01(\tR\x11\x64stAccountAddress\x12:\n\x06\x61mount\x18\x06 \x01(\x0b\x32\".injective_accounts_rpc.CosmosCoinR\x06\x61mount\x12\x1f\n\x0b\x65xecuted_at\x18\x07 \x01(\x12R\nexecutedAt\":\n\nCosmosCoin\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount\"\x86\x01\n\x06Paging\x12\x14\n\x05total\x18\x01 \x01(\x12R\x05total\x12\x12\n\x04\x66rom\x18\x02 \x01(\x11R\x04\x66rom\x12\x0e\n\x02to\x18\x03 \x01(\x11R\x02to\x12.\n\x13\x63ount_by_subaccount\x18\x04 \x01(\x12R\x11\x63ountBySubaccount\x12\x12\n\x04next\x18\x05 \x03(\tR\x04next\"\x8a\x01\n\x1dSubaccountOrderSummaryRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\'\n\x0forder_direction\x18\x03 \x01(\tR\x0eorderDirection\"\x84\x01\n\x1eSubaccountOrderSummaryResponse\x12*\n\x11spot_orders_total\x18\x01 \x01(\x12R\x0fspotOrdersTotal\x12\x36\n\x17\x64\x65rivative_orders_total\x18\x02 \x01(\x12R\x15\x64\x65rivativeOrdersTotal\"O\n\x0eRewardsRequest\x12\x14\n\x05\x65poch\x18\x01 \x01(\x12R\x05\x65poch\x12\'\n\x0f\x61\x63\x63ount_address\x18\x02 \x01(\tR\x0e\x61\x63\x63ountAddress\"K\n\x0fRewardsResponse\x12\x38\n\x07rewards\x18\x01 \x03(\x0b\x32\x1e.injective_accounts_rpc.RewardR\x07rewards\"\x90\x01\n\x06Reward\x12\'\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x36\n\x07rewards\x18\x02 \x03(\x0b\x32\x1c.injective_accounts_rpc.CoinR\x07rewards\x12%\n\x0e\x64istributed_at\x18\x03 \x01(\x12R\rdistributedAt\"Q\n\x04\x43oin\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount\x12\x1b\n\tusd_value\x18\x03 \x01(\tR\x08usdValue\"C\n\x18StreamAccountDataRequest\x12\'\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\tR\x0e\x61\x63\x63ountAddress\"\xde\x03\n\x19StreamAccountDataResponse\x12^\n\x12subaccount_balance\x18\x01 \x01(\x0b\x32/.injective_accounts_rpc.SubaccountBalanceResultR\x11subaccountBalance\x12\x43\n\x08position\x18\x02 \x01(\x0b\x32\'.injective_accounts_rpc.PositionsResultR\x08position\x12\x39\n\x05trade\x18\x03 \x01(\x0b\x32#.injective_accounts_rpc.TradeResultR\x05trade\x12\x39\n\x05order\x18\x04 \x01(\x0b\x32#.injective_accounts_rpc.OrderResultR\x05order\x12O\n\rorder_history\x18\x05 \x01(\x0b\x32*.injective_accounts_rpc.OrderHistoryResultR\x0corderHistory\x12U\n\x0f\x66unding_payment\x18\x06 \x01(\x0b\x32,.injective_accounts_rpc.FundingPaymentResultR\x0e\x66undingPayment\"|\n\x17SubaccountBalanceResult\x12\x43\n\x07\x62\x61lance\x18\x01 \x01(\x0b\x32).injective_accounts_rpc.SubaccountBalanceR\x07\x62\x61lance\x12\x1c\n\ttimestamp\x18\x02 \x01(\x12R\ttimestamp\"m\n\x0fPositionsResult\x12<\n\x08position\x18\x01 \x01(\x0b\x32 .injective_accounts_rpc.PositionR\x08position\x12\x1c\n\ttimestamp\x18\x02 \x01(\x12R\ttimestamp\"\xe1\x02\n\x08Position\x12\x16\n\x06ticker\x18\x01 \x01(\tR\x06ticker\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x03 \x01(\tR\x0csubaccountId\x12\x1c\n\tdirection\x18\x04 \x01(\tR\tdirection\x12\x1a\n\x08quantity\x18\x05 \x01(\tR\x08quantity\x12\x1f\n\x0b\x65ntry_price\x18\x06 \x01(\tR\nentryPrice\x12\x16\n\x06margin\x18\x07 \x01(\tR\x06margin\x12+\n\x11liquidation_price\x18\x08 \x01(\tR\x10liquidationPrice\x12\x1d\n\nmark_price\x18\t \x01(\tR\tmarkPrice\x12\x1d\n\nupdated_at\x18\n \x01(\x12R\tupdatedAt\x12\x1d\n\ncreated_at\x18\x0b \x01(\x12R\tcreatedAt\"\xf5\x01\n\x0bTradeResult\x12\x42\n\nspot_trade\x18\x01 \x01(\x0b\x32!.injective_accounts_rpc.SpotTradeH\x00R\tspotTrade\x12T\n\x10\x64\x65rivative_trade\x18\x02 \x01(\x0b\x32\'.injective_accounts_rpc.DerivativeTradeH\x00R\x0f\x64\x65rivativeTrade\x12%\n\x0eoperation_type\x18\x03 \x01(\tR\roperationType\x12\x1c\n\ttimestamp\x18\x04 \x01(\x12R\ttimestampB\x07\n\x05trade\"\xad\x03\n\tSpotTrade\x12\x1d\n\norder_hash\x18\x01 \x01(\tR\torderHash\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x03 \x01(\tR\x08marketId\x12\x30\n\x14trade_execution_type\x18\x04 \x01(\tR\x12tradeExecutionType\x12\'\n\x0ftrade_direction\x18\x05 \x01(\tR\x0etradeDirection\x12\x38\n\x05price\x18\x06 \x01(\x0b\x32\".injective_accounts_rpc.PriceLevelR\x05price\x12\x10\n\x03\x66\x65\x65\x18\x07 \x01(\tR\x03\x66\x65\x65\x12\x1f\n\x0b\x65xecuted_at\x18\x08 \x01(\x12R\nexecutedAt\x12#\n\rfee_recipient\x18\t \x01(\tR\x0c\x66\x65\x65Recipient\x12\x19\n\x08trade_id\x18\n \x01(\tR\x07tradeId\x12%\n\x0e\x65xecution_side\x18\x0b \x01(\tR\rexecutionSide\x12\x10\n\x03\x63id\x18\x0c \x01(\tR\x03\x63id\"\\\n\nPriceLevel\x12\x14\n\x05price\x18\x01 \x01(\tR\x05price\x12\x1a\n\x08quantity\x18\x02 \x01(\tR\x08quantity\x12\x1c\n\ttimestamp\x18\x03 \x01(\x12R\ttimestamp\"\xef\x03\n\x0f\x44\x65rivativeTrade\x12\x1d\n\norder_hash\x18\x01 \x01(\tR\torderHash\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x03 \x01(\tR\x08marketId\x12\x30\n\x14trade_execution_type\x18\x04 \x01(\tR\x12tradeExecutionType\x12%\n\x0eis_liquidation\x18\x05 \x01(\x08R\risLiquidation\x12L\n\x0eposition_delta\x18\x06 \x01(\x0b\x32%.injective_accounts_rpc.PositionDeltaR\rpositionDelta\x12\x16\n\x06payout\x18\x07 \x01(\tR\x06payout\x12\x10\n\x03\x66\x65\x65\x18\x08 \x01(\tR\x03\x66\x65\x65\x12\x1f\n\x0b\x65xecuted_at\x18\t \x01(\x12R\nexecutedAt\x12#\n\rfee_recipient\x18\n \x01(\tR\x0c\x66\x65\x65Recipient\x12\x19\n\x08trade_id\x18\x0b \x01(\tR\x07tradeId\x12%\n\x0e\x65xecution_side\x18\x0c \x01(\tR\rexecutionSide\x12\x10\n\x03\x63id\x18\r \x01(\tR\x03\x63id\x12\x10\n\x03pnl\x18\x0e \x01(\tR\x03pnl\"\xbb\x01\n\rPositionDelta\x12\'\n\x0ftrade_direction\x18\x01 \x01(\tR\x0etradeDirection\x12\'\n\x0f\x65xecution_price\x18\x02 \x01(\tR\x0e\x65xecutionPrice\x12-\n\x12\x65xecution_quantity\x18\x03 \x01(\tR\x11\x65xecutionQuantity\x12)\n\x10\x65xecution_margin\x18\x04 \x01(\tR\x0f\x65xecutionMargin\"\xff\x01\n\x0bOrderResult\x12G\n\nspot_order\x18\x01 \x01(\x0b\x32&.injective_accounts_rpc.SpotLimitOrderH\x00R\tspotOrder\x12Y\n\x10\x64\x65rivative_order\x18\x02 \x01(\x0b\x32,.injective_accounts_rpc.DerivativeLimitOrderH\x00R\x0f\x64\x65rivativeOrder\x12%\n\x0eoperation_type\x18\x03 \x01(\tR\roperationType\x12\x1c\n\ttimestamp\x18\x04 \x01(\x12R\ttimestampB\x07\n\x05order\"\xb8\x03\n\x0eSpotLimitOrder\x12\x1d\n\norder_hash\x18\x01 \x01(\tR\torderHash\x12\x1d\n\norder_side\x18\x02 \x01(\tR\torderSide\x12\x1b\n\tmarket_id\x18\x03 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x04 \x01(\tR\x0csubaccountId\x12\x14\n\x05price\x18\x05 \x01(\tR\x05price\x12\x1a\n\x08quantity\x18\x06 \x01(\tR\x08quantity\x12+\n\x11unfilled_quantity\x18\x07 \x01(\tR\x10unfilledQuantity\x12#\n\rtrigger_price\x18\x08 \x01(\tR\x0ctriggerPrice\x12#\n\rfee_recipient\x18\t \x01(\tR\x0c\x66\x65\x65Recipient\x12\x14\n\x05state\x18\n \x01(\tR\x05state\x12\x1d\n\ncreated_at\x18\x0b \x01(\x12R\tcreatedAt\x12\x1d\n\nupdated_at\x18\x0c \x01(\x12R\tupdatedAt\x12\x17\n\x07tx_hash\x18\r \x01(\tR\x06txHash\x12\x10\n\x03\x63id\x18\x0e \x01(\tR\x03\x63id\"\xd7\x05\n\x14\x44\x65rivativeLimitOrder\x12\x1d\n\norder_hash\x18\x01 \x01(\tR\torderHash\x12\x1d\n\norder_side\x18\x02 \x01(\tR\torderSide\x12\x1b\n\tmarket_id\x18\x03 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x04 \x01(\tR\x0csubaccountId\x12$\n\x0eis_reduce_only\x18\x05 \x01(\x08R\x0cisReduceOnly\x12\x16\n\x06margin\x18\x06 \x01(\tR\x06margin\x12\x14\n\x05price\x18\x07 \x01(\tR\x05price\x12\x1a\n\x08quantity\x18\x08 \x01(\tR\x08quantity\x12+\n\x11unfilled_quantity\x18\t \x01(\tR\x10unfilledQuantity\x12#\n\rtrigger_price\x18\n \x01(\tR\x0ctriggerPrice\x12#\n\rfee_recipient\x18\x0b \x01(\tR\x0c\x66\x65\x65Recipient\x12\x14\n\x05state\x18\x0c \x01(\tR\x05state\x12\x1d\n\ncreated_at\x18\r \x01(\x12R\tcreatedAt\x12\x1d\n\nupdated_at\x18\x0e \x01(\x12R\tupdatedAt\x12!\n\x0corder_number\x18\x0f \x01(\x12R\x0borderNumber\x12\x1d\n\norder_type\x18\x10 \x01(\tR\torderType\x12%\n\x0eis_conditional\x18\x11 \x01(\x08R\risConditional\x12\x1d\n\ntrigger_at\x18\x12 \x01(\x04R\ttriggerAt\x12*\n\x11placed_order_hash\x18\x13 \x01(\tR\x0fplacedOrderHash\x12%\n\x0e\x65xecution_type\x18\x14 \x01(\tR\rexecutionType\x12\x17\n\x07tx_hash\x18\x15 \x01(\tR\x06txHash\x12\x10\n\x03\x63id\x18\x16 \x01(\tR\x03\x63id\"\xb0\x02\n\x12OrderHistoryResult\x12X\n\x12spot_order_history\x18\x01 \x01(\x0b\x32(.injective_accounts_rpc.SpotOrderHistoryH\x00R\x10spotOrderHistory\x12j\n\x18\x64\x65rivative_order_history\x18\x02 \x01(\x0b\x32..injective_accounts_rpc.DerivativeOrderHistoryH\x00R\x16\x64\x65rivativeOrderHistory\x12%\n\x0eoperation_type\x18\x03 \x01(\tR\roperationType\x12\x1c\n\ttimestamp\x18\x04 \x01(\x12R\ttimestampB\x0f\n\rorder_history\"\xf3\x03\n\x10SpotOrderHistory\x12\x1d\n\norder_hash\x18\x01 \x01(\tR\torderHash\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x1b\n\tis_active\x18\x03 \x01(\x08R\x08isActive\x12#\n\rsubaccount_id\x18\x04 \x01(\tR\x0csubaccountId\x12%\n\x0e\x65xecution_type\x18\x05 \x01(\tR\rexecutionType\x12\x1d\n\norder_type\x18\x06 \x01(\tR\torderType\x12\x14\n\x05price\x18\x07 \x01(\tR\x05price\x12#\n\rtrigger_price\x18\x08 \x01(\tR\x0ctriggerPrice\x12\x1a\n\x08quantity\x18\t \x01(\tR\x08quantity\x12\'\n\x0f\x66illed_quantity\x18\n \x01(\tR\x0e\x66illedQuantity\x12\x14\n\x05state\x18\x0b \x01(\tR\x05state\x12\x1d\n\ncreated_at\x18\x0c \x01(\x12R\tcreatedAt\x12\x1d\n\nupdated_at\x18\r \x01(\x12R\tupdatedAt\x12\x1c\n\tdirection\x18\x0e \x01(\tR\tdirection\x12\x17\n\x07tx_hash\x18\x0f \x01(\tR\x06txHash\x12\x10\n\x03\x63id\x18\x10 \x01(\tR\x03\x63id\"\xa9\x05\n\x16\x44\x65rivativeOrderHistory\x12\x1d\n\norder_hash\x18\x01 \x01(\tR\torderHash\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x1b\n\tis_active\x18\x03 \x01(\x08R\x08isActive\x12#\n\rsubaccount_id\x18\x04 \x01(\tR\x0csubaccountId\x12%\n\x0e\x65xecution_type\x18\x05 \x01(\tR\rexecutionType\x12\x1d\n\norder_type\x18\x06 \x01(\tR\torderType\x12\x14\n\x05price\x18\x07 \x01(\tR\x05price\x12#\n\rtrigger_price\x18\x08 \x01(\tR\x0ctriggerPrice\x12\x1a\n\x08quantity\x18\t \x01(\tR\x08quantity\x12\'\n\x0f\x66illed_quantity\x18\n \x01(\tR\x0e\x66illedQuantity\x12\x14\n\x05state\x18\x0b \x01(\tR\x05state\x12\x1d\n\ncreated_at\x18\x0c \x01(\x12R\tcreatedAt\x12\x1d\n\nupdated_at\x18\r \x01(\x12R\tupdatedAt\x12$\n\x0eis_reduce_only\x18\x0e \x01(\x08R\x0cisReduceOnly\x12\x1c\n\tdirection\x18\x0f \x01(\tR\tdirection\x12%\n\x0eis_conditional\x18\x10 \x01(\x08R\risConditional\x12\x1d\n\ntrigger_at\x18\x11 \x01(\x04R\ttriggerAt\x12*\n\x11placed_order_hash\x18\x12 \x01(\tR\x0fplacedOrderHash\x12\x16\n\x06margin\x18\x13 \x01(\tR\x06margin\x12\x17\n\x07tx_hash\x18\x14 \x01(\tR\x06txHash\x12\x10\n\x03\x63id\x18\x15 \x01(\tR\x03\x63id\"\xae\x01\n\x14\x46undingPaymentResult\x12Q\n\x10\x66unding_payments\x18\x01 \x01(\x0b\x32&.injective_accounts_rpc.FundingPaymentR\x0f\x66undingPayments\x12%\n\x0eoperation_type\x18\x02 \x01(\tR\roperationType\x12\x1c\n\ttimestamp\x18\x04 \x01(\x12R\ttimestamp\"\x88\x01\n\x0e\x46undingPayment\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12\x16\n\x06\x61mount\x18\x03 \x01(\tR\x06\x61mount\x12\x1c\n\ttimestamp\x18\x04 \x01(\x12R\ttimestamp2\xdc\t\n\x14InjectiveAccountsRPC\x12`\n\tPortfolio\x12(.injective_accounts_rpc.PortfolioRequest\x1a).injective_accounts_rpc.PortfolioResponse\x12\x66\n\x0bOrderStates\x12*.injective_accounts_rpc.OrderStatesRequest\x1a+.injective_accounts_rpc.OrderStatesResponse\x12r\n\x0fSubaccountsList\x12..injective_accounts_rpc.SubaccountsListRequest\x1a/.injective_accounts_rpc.SubaccountsListResponse\x12\x87\x01\n\x16SubaccountBalancesList\x12\x35.injective_accounts_rpc.SubaccountBalancesListRequest\x1a\x36.injective_accounts_rpc.SubaccountBalancesListResponse\x12\x90\x01\n\x19SubaccountBalanceEndpoint\x12\x38.injective_accounts_rpc.SubaccountBalanceEndpointRequest\x1a\x39.injective_accounts_rpc.SubaccountBalanceEndpointResponse\x12\x8c\x01\n\x17StreamSubaccountBalance\x12\x36.injective_accounts_rpc.StreamSubaccountBalanceRequest\x1a\x37.injective_accounts_rpc.StreamSubaccountBalanceResponse0\x01\x12x\n\x11SubaccountHistory\x12\x30.injective_accounts_rpc.SubaccountHistoryRequest\x1a\x31.injective_accounts_rpc.SubaccountHistoryResponse\x12\x87\x01\n\x16SubaccountOrderSummary\x12\x35.injective_accounts_rpc.SubaccountOrderSummaryRequest\x1a\x36.injective_accounts_rpc.SubaccountOrderSummaryResponse\x12Z\n\x07Rewards\x12&.injective_accounts_rpc.RewardsRequest\x1a\'.injective_accounts_rpc.RewardsResponse\x12z\n\x11StreamAccountData\x12\x30.injective_accounts_rpc.StreamAccountDataRequest\x1a\x31.injective_accounts_rpc.StreamAccountDataResponse0\x01\x42\xc2\x01\n\x1a\x63om.injective_accounts_rpcB\x19InjectiveAccountsRpcProtoP\x01Z\x19/injective_accounts_rpcpb\xa2\x02\x03IXX\xaa\x02\x14InjectiveAccountsRpc\xca\x02\x14InjectiveAccountsRpc\xe2\x02 InjectiveAccountsRpc\\GPBMetadata\xea\x02\x14InjectiveAccountsRpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_accounts_rpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.injective_accounts_rpcB\031InjectiveAccountsRpcProtoP\001Z\031/injective_accounts_rpcpb\242\002\003IXX\252\002\024InjectiveAccountsRpc\312\002\024InjectiveAccountsRpc\342\002 InjectiveAccountsRpc\\GPBMetadata\352\002\024InjectiveAccountsRpc'
  _globals['_PORTFOLIOREQUEST']._serialized_start=65
  _globals['_PORTFOLIOREQUEST']._serialized_end=124
  _globals['_PORTFOLIORESPONSE']._serialized_start=126
  _globals['_PORTFOLIORESPONSE']._serialized_end=217
  _globals['_ACCOUNTPORTFOLIO']._serialized_start=220
  _globals['_ACCOUNTPORTFOLIO']._serialized_end=481
  _globals['_SUBACCOUNTPORTFOLIO']._serialized_start=484
  _globals['_SUBACCOUNTPORTFOLIO']._serialized_end=665
  _globals['_ORDERSTATESREQUEST']._serialized_start=667
  _globals['_ORDERSTATESREQUEST']._serialized_end=787
  _globals['_ORDERSTATESRESPONSE']._serialized_start=790
  _globals['_ORDERSTATESRESPONSE']._serialized_end=995
  _globals['_ORDERSTATERECORD']._serialized_start=998
  _globals['_ORDERSTATERECORD']._serialized_end=1393
  _globals['_SUBACCOUNTSLISTREQUEST']._serialized_start=1395
  _globals['_SUBACCOUNTSLISTREQUEST']._serialized_end=1460
  _globals['_SUBACCOUNTSLISTRESPONSE']._serialized_start=1462
  _globals['_SUBACCOUNTSLISTRESPONSE']._serialized_end=1521
  _globals['_SUBACCOUNTBALANCESLISTREQUEST']._serialized_start=1523
  _globals['_SUBACCOUNTBALANCESLISTREQUEST']._serialized_end=1615
  _globals['_SUBACCOUNTBALANCESLISTRESPONSE']._serialized_start=1617
  _globals['_SUBACCOUNTBALANCESLISTRESPONSE']._serialized_end=1720
  _globals['_SUBACCOUNTBALANCE']._serialized_start=1723
  _globals['_SUBACCOUNTBALANCE']._serialized_end=1911
  _globals['_SUBACCOUNTDEPOSIT']._serialized_start=1914
  _globals['_SUBACCOUNTDEPOSIT']._serialized_end=2111
  _globals['_SUBACCOUNTBALANCEENDPOINTREQUEST']._serialized_start=2113
  _globals['_SUBACCOUNTBALANCEENDPOINTREQUEST']._serialized_end=2206
  _globals['_SUBACCOUNTBALANCEENDPOINTRESPONSE']._serialized_start=2208
  _globals['_SUBACCOUNTBALANCEENDPOINTRESPONSE']._serialized_end=2312
  _globals['_STREAMSUBACCOUNTBALANCEREQUEST']._serialized_start=2314
  _globals['_STREAMSUBACCOUNTBALANCEREQUEST']._serialized_end=2407
  _globals['_STREAMSUBACCOUNTBALANCERESPONSE']._serialized_start=2410
  _globals['_STREAMSUBACCOUNTBALANCERESPONSE']._serialized_end=2542
  _globals['_SUBACCOUNTHISTORYREQUEST']._serialized_start=2545
  _globals['_SUBACCOUNTHISTORYREQUEST']._serialized_end=2738
  _globals['_SUBACCOUNTHISTORYRESPONSE']._serialized_start=2741
  _globals['_SUBACCOUNTHISTORYRESPONSE']._serialized_end=2905
  _globals['_SUBACCOUNTBALANCETRANSFER']._serialized_start=2908
  _globals['_SUBACCOUNTBALANCETRANSFER']._serialized_end=3249
  _globals['_COSMOSCOIN']._serialized_start=3251
  _globals['_COSMOSCOIN']._serialized_end=3309
  _globals['_PAGING']._serialized_start=3312
  _globals['_PAGING']._serialized_end=3446
  _globals['_SUBACCOUNTORDERSUMMARYREQUEST']._serialized_start=3449
  _globals['_SUBACCOUNTORDERSUMMARYREQUEST']._serialized_end=3587
  _globals['_SUBACCOUNTORDERSUMMARYRESPONSE']._serialized_start=3590
  _globals['_SUBACCOUNTORDERSUMMARYRESPONSE']._serialized_end=3722
  _globals['_REWARDSREQUEST']._serialized_start=3724
  _globals['_REWARDSREQUEST']._serialized_end=3803
  _globals['_REWARDSRESPONSE']._serialized_start=3805
  _globals['_REWARDSRESPONSE']._serialized_end=3880
  _globals['_REWARD']._serialized_start=3883
  _globals['_REWARD']._serialized_end=4027
  _globals['_COIN']._serialized_start=4029
  _globals['_COIN']._serialized_end=4110
  _globals['_STREAMACCOUNTDATAREQUEST']._serialized_start=4112
  _globals['_STREAMACCOUNTDATAREQUEST']._serialized_end=4179
  _globals['_STREAMACCOUNTDATARESPONSE']._serialized_start=4182
  _globals['_STREAMACCOUNTDATARESPONSE']._serialized_end=4660
  _globals['_SUBACCOUNTBALANCERESULT']._serialized_start=4662
  _globals['_SUBACCOUNTBALANCERESULT']._serialized_end=4786
  _globals['_POSITIONSRESULT']._serialized_start=4788
  _globals['_POSITIONSRESULT']._serialized_end=4897
  _globals['_POSITION']._serialized_start=4900
  _globals['_POSITION']._serialized_end=5253
  _globals['_TRADERESULT']._serialized_start=5256
  _globals['_TRADERESULT']._serialized_end=5501
  _globals['_SPOTTRADE']._serialized_start=5504
  _globals['_SPOTTRADE']._serialized_end=5933
  _globals['_PRICELEVEL']._serialized_start=5935
  _globals['_PRICELEVEL']._serialized_end=6027
  _globals['_DERIVATIVETRADE']._serialized_start=6030
  _globals['_DERIVATIVETRADE']._serialized_end=6525
  _globals['_POSITIONDELTA']._serialized_start=6528
  _globals['_POSITIONDELTA']._serialized_end=6715
  _globals['_ORDERRESULT']._serialized_start=6718
  _globals['_ORDERRESULT']._serialized_end=6973
  _globals['_SPOTLIMITORDER']._serialized_start=6976
  _globals['_SPOTLIMITORDER']._serialized_end=7416
  _globals['_DERIVATIVELIMITORDER']._serialized_start=7419
  _globals['_DERIVATIVELIMITORDER']._serialized_end=8146
  _globals['_ORDERHISTORYRESULT']._serialized_start=8149
  _globals['_ORDERHISTORYRESULT']._serialized_end=8453
  _globals['_SPOTORDERHISTORY']._serialized_start=8456
  _globals['_SPOTORDERHISTORY']._serialized_end=8955
  _globals['_DERIVATIVEORDERHISTORY']._serialized_start=8958
  _globals['_DERIVATIVEORDERHISTORY']._serialized_end=9639
  _globals['_FUNDINGPAYMENTRESULT']._serialized_start=9642
  _globals['_FUNDINGPAYMENTRESULT']._serialized_end=9816
  _globals['_FUNDINGPAYMENT']._serialized_start=9819
  _globals['_FUNDINGPAYMENT']._serialized_end=9955
  _globals['_INJECTIVEACCOUNTSRPC']._serialized_start=9958
  _globals['_INJECTIVEACCOUNTSRPC']._serialized_end=11202
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/insurance/v1beta1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.injective.insurance.v1beta1 import insurance_pb2 as injective_dot_insurance_dot_v1beta1_dot_insurance__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)injective/insurance/v1beta1/genesis.proto\x12\x1binjective.insurance.v1beta1\x1a+injective/insurance/v1beta1/insurance.proto\x1a\x14gogoproto/gogo.proto\"\x82\x03\n\x0cGenesisState\x12\x41\n\x06params\x18\x01 \x01(\x0b\x32#.injective.insurance.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\x12Y\n\x0finsurance_funds\x18\x02 \x03(\x0b\x32*.injective.insurance.v1beta1.InsuranceFundB\x04\xc8\xde\x1f\x00R\x0einsuranceFunds\x12\x66\n\x13redemption_schedule\x18\x03 \x03(\x0b\x32/.injective.insurance.v1beta1.RedemptionScheduleB\x04\xc8\xde\x1f\x00R\x12redemptionSchedule\x12-\n\x13next_share_denom_id\x18\x04 \x01(\x04R\x10nextShareDenomId\x12=\n\x1bnext_redemption_schedule_id\x18\x05 \x01(\x04R\x18nextRedemptionScheduleIdB\x8e\x02\n\x1f\x63om.injective.insurance.v1beta1B\x0cGenesisProtoP\x01ZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/types\xa2\x02\x03IIX\xaa\x02\x1bInjective.Insurance.V1beta1\xca\x02\x1bInjective\\Insurance\\V1beta1\xe2\x02\'Injective\\Insurance\\V1beta1\\GPBMetadata\xea\x02\x1dInjective::Insurance::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.insurance.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.injective.insurance.v1beta1B\014GenesisProtoP\001ZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/types\242\002\003IIX\252\002\033Injective.Insurance.V1beta1\312\002\033Injective\\Insurance\\V1beta1\342\002\'Injective\\Insurance\\V1beta1\\GPBMetadata\352\002\035Injective::Insurance::V1beta1'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['insurance_funds']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['insurance_funds']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['redemption_schedule']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['redemption_schedule']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=142
  _globals['_GENESISSTATE']._serialized_end=528
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/store/v1beta1/commit_info.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&cosmos/store/v1beta1/commit_info.proto\x12\x14\x63osmos.store.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb2\x01\n\nCommitInfo\x12\x18\n\x07version\x18\x01 \x01(\x03R\x07version\x12\x46\n\x0bstore_infos\x18\x02 \x03(\x0b\x32\x1f.cosmos.store.v1beta1.StoreInfoB\x04\xc8\xde\x1f\x00R\nstoreInfos\x12\x42\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\ttimestamp\"b\n\tStoreInfo\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x41\n\tcommit_id\x18\x02 \x01(\x0b\x32\x1e.cosmos.store.v1beta1.CommitIDB\x04\xc8\xde\x1f\x00R\x08\x63ommitId\">\n\x08\x43ommitID\x12\x18\n\x07version\x18\x01 \x01(\x03R\x07version\x12\x12\n\x04hash\x18\x02 \x01(\x0cR\x04hash:\x04\x98\xa0\x1f\x00\x42\xb7\x01\n\x18\x63om.cosmos.store.v1beta1B\x0f\x43ommitInfoProtoP\x01Z\x18\x63osmossdk.io/store/types\xa2\x02\x03\x43SX\xaa\x02\x14\x43osmos.Store.V1beta1\xca\x02\x14\x43osmos\\Store\\V1beta1\xe2\x02 Cosmos\\Store\\V1beta1\\GPBMetadata\xea\x02\x16\x43osmos::Store::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.store.v1beta1.commit_info_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030com.cosmos.store.v1beta1B\017CommitInfoProtoP\001Z\030cosmossdk.io/store/types\242\002\003CSX\252\002\024Cosmos.Store.V1beta1\312\002\024Cosmos\\Store\\V1beta1\342\002 Cosmos\\Store\\V1beta1\\GPBMetadata\352\002\026Cosmos::Store::V1beta1'
  _globals['_COMMITINFO'].fields_by_name['store_infos']._loaded_options = None
  _globals['_COMMITINFO'].fields_by_name['store_infos']._serialized_options = b'\310\336\037\000'
  _globals['_COMMITINFO'].fields_by_name['timestamp']._loaded_options = None
  _globals['_COMMITINFO'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_STOREINFO'].fields_by_name['commit_id']._loaded_options = None
  _globals['_STOREINFO'].fields_by_name['commit_id']._serialized_options = b'\310\336\037\000'
  _globals['_COMMITID']._loaded_options = None
  _globals['_COMMITID']._serialized_options = b'\230\240\037\000'
  _globals['_COMMITINFO']._serialized_start=120
  _globals['_COMMITINFO']._serialized_end=298
  _globals['_STOREINFO']._serialized_start=300
  _globals['_STOREINFO']._serialized_end=398
  _globals['_COMMITID']._serialized_start=400
  _globals['_COMMITID']._serialized_end=462
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/types/v1beta2/params.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cometbft.types.v1beta1 import params_pb2 as cometbft_dot_types_dot_v1beta1_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cometbft/types/v1beta2/params.proto\x12\x16\x63ometbft.types.v1beta2\x1a\x14gogoproto/gogo.proto\x1a#cometbft/types/v1beta1/params.proto\"\x98\x02\n\x0f\x43onsensusParams\x12\x39\n\x05\x62lock\x18\x01 \x01(\x0b\x32#.cometbft.types.v1beta2.BlockParamsR\x05\x62lock\x12\x42\n\x08\x65vidence\x18\x02 \x01(\x0b\x32&.cometbft.types.v1beta1.EvidenceParamsR\x08\x65vidence\x12\x45\n\tvalidator\x18\x03 \x01(\x0b\x32\'.cometbft.types.v1beta1.ValidatorParamsR\tvalidator\x12?\n\x07version\x18\x04 \x01(\x0b\x32%.cometbft.types.v1beta1.VersionParamsR\x07version\"I\n\x0b\x42lockParams\x12\x1b\n\tmax_bytes\x18\x01 \x01(\x03R\x08maxBytes\x12\x17\n\x07max_gas\x18\x02 \x01(\x03R\x06maxGasJ\x04\x08\x03\x10\x04\x42\xe0\x01\n\x1a\x63om.cometbft.types.v1beta2B\x0bParamsProtoP\x01Z7github.com/cometbft/cometbft/api/cometbft/types/v1beta2\xa2\x02\x03\x43TX\xaa\x02\x16\x43ometbft.Types.V1beta2\xca\x02\x16\x43ometbft\\Types\\V1beta2\xe2\x02\"Cometbft\\Types\\V1beta2\\GPBMetadata\xea\x02\x18\x43ometbft::Types::V1beta2\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.types.v1beta2.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.cometbft.types.v1beta2B\013ParamsProtoP\001Z7github.com/cometbft/cometbft/api/cometbft/types/v1beta2\242\002\003CTX\252\002\026Cometbft.Types.V1beta2\312\002\026Cometbft\\Types\\V1beta2\342\002\"Cometbft\\Types\\V1beta2\\GPBMetadata\352\002\030Cometbft::Types::V1beta2\250\342\036\001'
  _globals['_CONSENSUSPARAMS']._serialized_start=123
  _globals['_CONSENSUSPARAMS']._serialized_end=403
  _globals['_BLOCKPARAMS']._serialized_start=405
  _globals['_BLOCKPARAMS']._serialized_end=478
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1beta1/value.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#google/api/expr/v1beta1/value.proto\x12\x17google.api.expr.v1beta1\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xca\x04\n\x05Value\x12;\n\nnull_value\x18\x01 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00R\tnullValue\x12\x1f\n\nbool_value\x18\x02 \x01(\x08H\x00R\tboolValue\x12!\n\x0bint64_value\x18\x03 \x01(\x03H\x00R\nint64Value\x12#\n\x0cuint64_value\x18\x04 \x01(\x04H\x00R\x0buint64Value\x12#\n\x0c\x64ouble_value\x18\x05 \x01(\x01H\x00R\x0b\x64oubleValue\x12#\n\x0cstring_value\x18\x06 \x01(\tH\x00R\x0bstringValue\x12!\n\x0b\x62ytes_value\x18\x07 \x01(\x0cH\x00R\nbytesValue\x12\x43\n\nenum_value\x18\t \x01(\x0b\x32\".google.api.expr.v1beta1.EnumValueH\x00R\tenumValue\x12\x39\n\x0cobject_value\x18\n \x01(\x0b\x32\x14.google.protobuf.AnyH\x00R\x0bobjectValue\x12@\n\tmap_value\x18\x0b \x01(\x0b\x32!.google.api.expr.v1beta1.MapValueH\x00R\x08mapValue\x12\x43\n\nlist_value\x18\x0c \x01(\x0b\x32\".google.api.expr.v1beta1.ListValueH\x00R\tlistValue\x12\x1f\n\ntype_value\x18\x0f \x01(\tH\x00R\ttypeValueB\x06\n\x04kind\"5\n\tEnumValue\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\x12\x14\n\x05value\x18\x02 \x01(\x05R\x05value\"C\n\tListValue\x12\x36\n\x06values\x18\x01 \x03(\x0b\x32\x1e.google.api.expr.v1beta1.ValueR\x06values\"\xbe\x01\n\x08MapValue\x12\x41\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\'.google.api.expr.v1beta1.MapValue.EntryR\x07\x65ntries\x1ao\n\x05\x45ntry\x12\x30\n\x03key\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1beta1.ValueR\x03key\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32\x1e.google.api.expr.v1beta1.ValueR\x05valueB\xe8\x01\n\x1b\x63om.google.api.expr.v1beta1B\nValueProtoP\x01Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\xf8\x01\x01\xa2\x02\x03GAE\xaa\x02\x17Google.Api.Expr.V1beta1\xca\x02\x17Google\\Api\\Expr\\V1beta1\xe2\x02#Google\\Api\\Expr\\V1beta1\\GPBMetadata\xea\x02\x1aGoogle::Api::Expr::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.expr.v1beta1.value_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.google.api.expr.v1beta1B\nValueProtoP\001Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\370\001\001\242\002\003GAE\252\002\027Google.Api.Expr.V1beta1\312\002\027Google\\Api\\Expr\\V1beta1\342\002#Google\\Api\\Expr\\V1beta1\\GPBMetadata\352\002\032Google::Api::Expr::V1beta1'
  _globals['_VALUE']._serialized_start=122
  _globals['_VALUE']._serialized_end=708
  _globals['_ENUMVALUE']._serialized_start=710
  _globals['_ENUMVALUE']._serialized_end=763
  _globals['_LISTVALUE']._serialized_start=765
  _globals['_LISTVALUE']._serialized_end=832
  _globals['_MAPVALUE']._serialized_start=835
  _globals['_MAPVALUE']._serialized_end=1025
  _globals['_MAPVALUE_ENTRY']._serialized_start=914
  _globals['_MAPVALUE_ENTRY']._serialized_end=1025
# @@protoc_insertion_point(module_scope)
